@@ -49,18 +49,11 @@ void AppWindow::init()
 {
   //set_wmclass(m_strAppName, m_strTitle); //The docs say "Don't use this".
 
-  init_ui_manager();
   init_menus();
-  init_toolbars();
 
   //on_document_load(); //Show the document (even if it is empty).
 }
 
-void AppWindow::init_ui_manager()
-{
-  
-}
-
 void AppWindow::init_menus()
 {
   init_menus_file();
@@ -72,11 +65,6 @@ void AppWindow::init_menus()
   //Override this to add more menus.
 }
 
-void AppWindow::init_toolbars()
-{
-  
-}
-
 void AppWindow::on_menu_file_new()
 {
   new_instance();
