@@ -19,6 +19,7 @@
 #include "config.h"
 #include <glom/bakery/appwindow_withdoc.h>
 #include <glom/bakery/dialog_offersave.h>
+#include <libglom/utils.h>
 #include <giomm/file.h>
 #include <algorithm>
 #include <glibmm/i18n-lib.h>
@@ -150,7 +151,7 @@ bool AppWindow_WithDoc::open_document(const Glib::ustring& file_uri)
       ui_warning_load_failed(failure_code);
 
     //Make sure that non-existant files are removed from the history list:
-    if(failure_code == Document::LOAD_FAILURE_CODE_NOT_FOUND)
+    if(failure_code == Glom::Utils::to_utype(Document::LoadFailureCodes::NOT_FOUND))
       document_history_remove(file_uri);
 
     //re-initialize document.
@@ -342,13 +343,13 @@ void AppWindow_WithDoc::offer_to_save_changes()
       //Respond to button that was clicked:
       switch(buttonClicked)
       {
-        case(SAVECHANGES_Save):
+        case(enumSaveChanges::Save):
         {
           on_menu_file_save(); //If File|Exit is in progress, this could cancel it.
           break;
         }
 
-        case(SAVECHANGES_Discard):
+        case(enumSaveChanges::Discard):
         {
           //Close if this save offer was a result of a FileClose (It probably always is):
           //close_mark_or_destroy();
@@ -356,7 +357,7 @@ void AppWindow_WithDoc::offer_to_save_changes()
           break;
         }
 
-        case(SAVECHANGES_Cancel): //Cancel.
+        case(enumSaveChanges::Cancel): //Cancel.
         {
           cancel_close_or_exit();
           break;
