@@ -20,6 +20,7 @@
 #include <gtkmm/box.h>
 #include <glom/bakery/dialog_offersave.h>
 #include <glom/appwindow.h>
+#include <libglom/utils.h>
 #include <glibmm/convert.h> 
 #include <glibmm/i18n-lib.h>
 
@@ -52,9 +53,9 @@ Dialog_OfferSave::Dialog_OfferSave(const Glib::ustring& file_uri)
   
   set_secondary_text(get_confirmation_message(file_uri));
 
-  add_button(_("Discard"), BUTTON_Discard);
-  auto cancel_button = add_button(_("_Cancel"), BUTTON_Cancel);
-  add_button(_("_Save"), BUTTON_Save);
+  add_button(_("Discard"), Glom::Utils::to_utype(enumButtons::Discard));
+  auto cancel_button = add_button(_("_Cancel"), Glom::Utils::to_utype(enumButtons::Cancel));
+  add_button(_("_Save"), Glom::Utils::to_utype(enumButtons::Save));
 
   // Otherwise Discard has focus initially which seems inconvenient:
   cancel_button->grab_focus();
