@@ -32,13 +32,13 @@ namespace Glom
 
 Box_WithButtons::Box_WithButtons()
 : Gtk::Box(Gtk::ORIENTATION_VERTICAL),
-  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, UiUtils::DEFAULT_SPACING_SMALL),
+  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, Utils::to_utype(UiUtils::DefaultSpacings::SMALL)),
   m_Button_Cancel(_("_Cancel"))
 {
   //m_pDocument = nullptr;
 
-  //set_border_width(UiUtils::DEFAULT_SPACING_SMALL);
-  set_spacing(UiUtils::DEFAULT_SPACING_SMALL);
+  //set_border_width(Utils::to_utype(UiUtils::DefaultSpacings::SMALL));
+  set_spacing(Utils::to_utype(UiUtils::DefaultSpacings::SMALL));
 
   //Connect signals:
   m_Button_Cancel.signal_clicked().connect(sigc::mem_fun(*this, &Box_WithButtons::on_Button_Cancel));
@@ -46,13 +46,13 @@ Box_WithButtons::Box_WithButtons()
 
 Box_WithButtons::Box_WithButtons(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
 : Gtk::Box(cobject),
-  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, UiUtils::DEFAULT_SPACING_SMALL),
+  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, Utils::to_utype(UiUtils::DefaultSpacings::SMALL)),
   m_Button_Cancel(_("_Cancel"))
 {
   //m_pDocument = nullptr;
 
-  //set_border_width(UiUtils::DEFAULT_SPACING_SMALL);
-  set_spacing(UiUtils::DEFAULT_SPACING_SMALL);
+  //set_border_width(Utils::to_utype(UiUtils::DefaultSpacings::SMALL));
+  set_spacing(Utils::to_utype(UiUtils::DefaultSpacings::SMALL));
 
   //Connect signals:
   m_Button_Cancel.signal_clicked().connect(sigc::mem_fun(*this, &Box_WithButtons::on_Button_Cancel));
@@ -60,7 +60,7 @@ Box_WithButtons::Box_WithButtons(BaseObjectType* cobject, const Glib::RefPtr<Gtk
 
 Box_WithButtons::Box_WithButtons(BaseObjectType* cobject)
 : Gtk::Box(cobject),
-  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, UiUtils::DEFAULT_SPACING_SMALL),
+  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, Utils::to_utype(UiUtils::DefaultSpacings::SMALL)),
   m_Button_Cancel(_("_Cancel"))
 {
 }
@@ -77,7 +77,7 @@ void Box_WithButtons::on_Button_Cancel()
 
 const Gtk::Window* Box_WithButtons::get_app_window() const
 {
-  Box_WithButtons* nonconst = const_cast<Box_WithButtons*>(this);
+  auto nonconst = const_cast<Box_WithButtons*>(this);
   return nonconst->get_app_window();
 }
   
@@ -86,11 +86,11 @@ Gtk::Window* Box_WithButtons::get_app_window()
   return dynamic_cast<Gtk::Window*>(get_toplevel());
 /*
 
-  Gtk::Widget* pWidget = get_parent();
+  auto pWidget = get_parent();
   while(pWidget)
   {
     //Is this widget a Gtk::Window?:
-    Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(pWidget);
+    auto pWindow = dynamic_cast<Gtk::Window*>(pWidget);
     if(pWindow)
     {
       //Yes, return it.
