@@ -57,10 +57,10 @@ public:
   void set_password(const Glib::ustring& password);
   void get_username_and_password(Glib::ustring& user, Glib::ustring& password) const;
 
-  virtual void load_from_document() override;
-  
   void set_self_hosted_user_and_password(const Glib::ustring& username, const Glib::ustring& password);
 
+  void load_from_document() override;
+
   /** Use this to override the data from load_from_document().
    * For instance, if you want to try to connect to a renamed database.
    */
