@@ -124,7 +124,7 @@ Dialog_Import_CSV::Dialog_Import_CSV(BaseObjectType* cobject, const Glib::RefPtr
   m_encoding_combo->signal_changed().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_combo_encoding_changed));
 
   // TODO: Reset parser encoding on selection changed.
-  m_parser = std::make_shared<CsvParser>(get_current_encoding().c_str());
+  m_parser = std::make_shared<CsvParser>(get_current_encoding());
   m_parser->signal_file_read_error().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_parser_file_read_error));
   m_parser->signal_have_display_name().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_parser_have_display_name));
   m_parser->signal_encoding_error().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_parser_encoding_error));
@@ -279,7 +279,7 @@ void Dialog_Import_CSV::encoding_data_func(const Gtk::TreeModel::iterator& iter,
   const auto name = (*iter)[m_encoding_columns.m_col_name];
   const auto charset = (*iter)[m_encoding_columns.m_col_charset];
 
-  renderer.set_property("text", encoding_display(name, charset));
+  renderer.property_text() = encoding_display(name, charset);
 }
 
 bool Dialog_Import_CSV::row_separator_func(const Glib::RefPtr<Gtk::TreeModel>& /* model */, const Gtk::TreeModel::iterator& iter) const
@@ -437,7 +437,7 @@ void Dialog_Import_CSV::begin_parse()
   m_sample_view->set_model(m_sample_model); // Empty model
   m_parser->clear();
 
-  m_parser->set_encoding(get_current_encoding().c_str());
+  m_parser->set_encoding(get_current_encoding());
 
   // Allow the Import button to be pressed when a field for the primary key
   // field is set. When the import button is pressed without the file being
@@ -526,7 +526,7 @@ void Dialog_Import_CSV::setup_sample_model(const CsvParser::type_row_strings& ro
 
 Gtk::TreeViewColumn* Dialog_Import_CSV::create_sample_column(const Glib::ustring& title, guint index)
 {
-  Gtk::TreeViewColumn* col = new Gtk::TreeViewColumn(title);
+  auto col = new Gtk::TreeViewColumn(title);
   auto cell = create_sample_cell(index);
   col->pack_start(*Gtk::manage(cell), true);
   col->set_cell_data_func(*cell, sigc::bind(sigc::mem_fun(*this, &Dialog_Import_CSV::field_data_func), index));
@@ -536,7 +536,7 @@ Gtk::TreeViewColumn* Dialog_Import_CSV::create_sample_column(const Glib::ustring
 
 Gtk::CellRendererCombo* Dialog_Import_CSV::create_sample_cell(guint index)
 {
-  Gtk::CellRendererCombo* cell = new Gtk::CellRendererCombo;
+  auto cell = new Gtk::CellRendererCombo;
   cell->property_model() = m_field_model_sorted;
   cell->property_text_column() = 0;
   cell->property_has_entry() = false;
@@ -553,9 +553,9 @@ void Dialog_Import_CSV::line_data_func(Gtk::CellRenderer* renderer, const Gtk::T
     throw std::logic_error("CellRenderer is not a CellRendererText in line_data_func");
 
   if(row == -1)
-    renderer_text->set_property("text", Glib::ustring(_("Target Field")));
+    renderer_text->property_text() = Glib::ustring(_("Target Field"));
   else
-    renderer_text->set_property("text", Glib::ustring::compose("%1", row + 1));
+    renderer_text->property_text() = Glib::ustring::compose("%1", row + 1);
 }
 
 void Dialog_Import_CSV::field_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter, guint column_number)
@@ -592,7 +592,7 @@ void Dialog_Import_CSV::field_data_func(Gtk::CellRenderer* renderer, const Gtk::
 
           if(field)
           {
-            if(field->get_glom_type() != Field::TYPE_IMAGE)
+            if(field->get_glom_type() != Field::glom_field_type::IMAGE)
             {
               /* Exported data is always stored in postgres format */
               bool success = false;
@@ -628,8 +628,8 @@ void Dialog_Import_CSV::field_data_func(Gtk::CellRenderer* renderer, const Gtk::
     }
   }
 
-  renderer_combo->set_property("text", text);
-  renderer_combo->set_property("editable", editable);
+  renderer_combo->property_text() = text;
+  renderer_combo->property_editable() = editable;
 }
 
 
@@ -676,7 +676,8 @@ void Dialog_Import_CSV::on_field_edited(const Glib::ustring& path, const Glib::u
 
 void Dialog_Import_CSV::validate_primary_key()
 {
-  if(get_parser_state() == (CsvParser::STATE_NONE | CsvParser::STATE_ENCODING_ERROR))
+  if(get_parser_state() == CsvParser::State::NONE
+   || get_parser_state() == CsvParser::State::ENCODING_ERROR)
   {
     m_error_label->hide();
     set_response_sensitive(Gtk::RESPONSE_ACCEPT, false);
