@@ -97,16 +97,16 @@ Glib::RefPtr<Gnome::Gda::Connection> PostgresCentralHosted::connect(const Glib::
   {
     connection = attempt_connect(port, database, username, password, fake_connection);
     connection_possible = true;
-    m_port = atoi(port.c_str());
+    m_port = std::stoi(port);
   }
   catch(const ExceptionConnection& ex)
   {
     // Remember port if only the database was missing
     connection_possible = false;
-    if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_DATABASE)
+    if(ex.get_failure_type() == ExceptionConnection::failure_type::NO_DATABASE)
     {
       connection_possible = true;
-      m_port = atoi(port.c_str());
+      m_port = std::stoi(port);
     }
   }
 
@@ -121,7 +121,7 @@ Glib::RefPtr<Gnome::Gda::Connection> PostgresCentralHosted::connect(const Glib::
       {
         connection = attempt_connect(port, database, username, password, fake_connection);
         connection_possible = true;
-        m_port = atoi(port.c_str());
+        m_port = std::stoi(port);
       }
       catch(const ExceptionConnection& ex)
       {
@@ -129,10 +129,10 @@ Glib::RefPtr<Gnome::Gda::Connection> PostgresCentralHosted::connect(const Glib::
         //show that a connection was possible with a previously-tried port: connection_possible = false;
 
         // Remember port if only the database was missing
-        if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_DATABASE)
+        if(ex.get_failure_type() == ExceptionConnection::failure_type::NO_DATABASE)
         {
           connection_possible = true;
-          m_port = atoi(port.c_str());
+          m_port = std::stoi(port);
         }
       }
 
@@ -145,14 +145,14 @@ Glib::RefPtr<Gnome::Gda::Connection> PostgresCentralHosted::connect(const Glib::
   if(connection)
   {
     //Remember working port:
-    m_port = atoi(port.c_str());
+    m_port = std::stoi(port);
   }
   else
   {
     if(connection_possible)
-      throw ExceptionConnection(ExceptionConnection::FAILURE_NO_DATABASE);
+      throw ExceptionConnection(ExceptionConnection::failure_type::NO_DATABASE);
     else
-      throw ExceptionConnection(ExceptionConnection::FAILURE_NO_SERVER);
+      throw ExceptionConnection(ExceptionConnection::failure_type::NO_SERVER);
   }
 
   return connection;
