@@ -96,10 +96,10 @@ Glib::RefPtr<Gnome::Gda::Connection> Sqlite::connect(const Glib::ustring& databa
     if(Glom::Utils::file_exists(db_dir) &&
       (db_dir->query_file_type() == Gio::FILE_TYPE_DIRECTORY))
     {
-      throw ExceptionConnection(ExceptionConnection::FAILURE_NO_DATABASE);
+      throw ExceptionConnection(ExceptionConnection::failure_type::NO_DATABASE);
     }
     else
-      throw ExceptionConnection(ExceptionConnection::FAILURE_NO_SERVER);
+      throw ExceptionConnection(ExceptionConnection::failure_type::NO_SERVER);
   }
 
   return connection;
@@ -176,7 +176,7 @@ bool Sqlite::add_column_to_server_operation(const Glib::RefPtr<Gnome::Gda::Serve
   return true;
 }
 
-bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vec_strings& fields_removed, const type_vec_const_fields& fields_added, const type_mapFieldChanges& fields_changed) throw()
+bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vec_strings& fields_removed, const type_vec_const_fields& fields_added, const type_mapFieldChanges& fields_changed) noexcept
 {
   static const gchar TEMPORARY_TABLE_NAME[] = "GLOM_TEMP_TABLE"; // TODO: Make sure this is unique.
   static const gchar TRANSACTION_NAME[] = "GLOM_RECREATE_TABLE_TRANSACTION";
@@ -211,7 +211,7 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
     {
       // If it was removed, and added again, then it has changed, so use the
       // definition from the added_fields vector.
-      auto iter = std::find_if(fields_added.begin(), fields_added.end(), predicate_FieldHasName<Field>(column->column_name));
+      auto iter = find_if_same_name(fields_added, column->column_name);
       if(iter == fields_added.end())
         continue;
       else
@@ -228,7 +228,7 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
       // Convert values to date or time, accordingly.
       switch(changed_iter->second->get_glom_type())
       {
-      case Field::TYPE_TEXT:
+      case Field::glom_field_type::TEXT:
         if(column->gtype == G_TYPE_BOOLEAN)
 	  trans_fields += "(CASE WHEN "+ DbUtils::escape_sql_id(column->column_name) + " = 1 THEN 'true' "
                                               "WHEN " + DbUtils::escape_sql_id(column->column_name) + " = 0 THEN 'false' "
@@ -240,7 +240,7 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
           trans_fields += "(CASE WHEN "+ DbUtils::escape_sql_id(column->column_name) + " IS NULL THEN '' "
                                               "WHEN " + DbUtils::escape_sql_id(column->column_name) + " IS NOT NULL THEN " + DbUtils::escape_sql_id(column->column_name) + " END)";
 	break;
-      case Field::TYPE_NUMERIC:
+      case Field::glom_field_type::NUMERIC:
         if(column->gtype == G_TYPE_BOOLEAN)
           trans_fields += "(CASE WHEN "+ DbUtils::escape_sql_id(column->column_name) + " = 0 THEN 0 "
                                               "WHEN " + DbUtils::escape_sql_id(column->column_name) + " != 0 THEN 1 "
@@ -250,7 +250,7 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
         else
           trans_fields += Glib::ustring("CAST(")+ DbUtils::escape_sql_id(column->column_name) + " AS real)";
         break;
-      case Field::TYPE_BOOLEAN:
+      case Field::glom_field_type::BOOLEAN:
         if(column->gtype == G_TYPE_STRING)
           trans_fields += "(CASE WHEN "+ DbUtils::escape_sql_id(column->column_name) + " = 'true' THEN 1 "
                                               "WHEN " + DbUtils::escape_sql_id(column->column_name) + " = 'false' THEN 0 "
@@ -264,19 +264,19 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
         else
           trans_fields += Glib::ustring(column->column_name) + " IS NOT NULL";
         break;
-      case Field::TYPE_DATE:
+      case Field::glom_field_type::DATE:
         if(column->gtype == G_TYPE_BOOLEAN || column->gtype == GDA_TYPE_BLOB || column->gtype == G_TYPE_DOUBLE)
           trans_fields += "NULL";
         else
           trans_fields += Glib::ustring("date(")+ DbUtils::escape_sql_id(column->column_name) + ')';
         break;
-      case Field::TYPE_TIME:
+      case Field::glom_field_type::TIME:
         if(column->gtype == G_TYPE_BOOLEAN || column->gtype == GDA_TYPE_BLOB || column->gtype == G_TYPE_DOUBLE)
           trans_fields += "NULL";
         else
           trans_fields += Glib::ustring("time(")+ DbUtils::escape_sql_id(column->column_name) + ')';
         break;
-      case Field::TYPE_IMAGE:
+      case Field::glom_field_type::IMAGE:
         if(column->gtype == GDA_TYPE_BLOB)
           trans_fields += column->column_name;
         else
@@ -314,13 +314,13 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
       {
         switch(field->get_glom_type())
         {
-        case Field::TYPE_NUMERIC:
+        case Field::glom_field_type::NUMERIC:
           trans_fields += '0';
           break;
-        case Field::TYPE_BOOLEAN:
+        case Field::glom_field_type::BOOLEAN:
           trans_fields += '0';
           break;
-        case Field::TYPE_TEXT:
+        case Field::glom_field_type::TEXT:
           trans_fields += "''";
           break;
         default:
@@ -397,7 +397,7 @@ bool Sqlite::drop_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection,
   return recreate_table(connection, table_name, type_vec_strings(1, field_name), type_vec_const_fields(), type_mapFieldChanges());
 }
 
-bool Sqlite::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& new_fields) throw()
+bool Sqlite::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& new_fields) noexcept
 {
   type_mapFieldChanges fields_changed;
 
