@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <libglom/data_structure/database_title.h>
@@ -25,7 +25,7 @@ namespace Glom
 
 DatabaseTitle::DatabaseTitle()
 {
-  m_translatable_item_type = TRANSLATABLE_TYPE_DATABASE_TITLE;
+  m_translatable_item_type = enumTranslatableItemType::DATABASE_TITLE;
 }
 
 DatabaseTitle::DatabaseTitle(const DatabaseTitle& src)
