@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_DATASTRUCTURE_DATABASE_TITLE_H
@@ -27,7 +27,7 @@ namespace Glom
 {
 
 /** This is a separate class, instead of just deriving Document from 
- * TranslatableItem, to avoid the need to use Document via sharedptr.
+ * TranslatableItem, to avoid the need to use Document via std::shared_ptr.
  */
 class DatabaseTitle
  : public TranslatableItem
@@ -35,7 +35,9 @@ class DatabaseTitle
 public:
   DatabaseTitle();
   DatabaseTitle(const DatabaseTitle& src);
+  DatabaseTitle(DatabaseTitle&& src) = delete;
   DatabaseTitle& operator=(const DatabaseTitle& src);
+  DatabaseTitle& operator=(DatabaseTitle&& src) = delete;
 };
 
 } //namespace Glom
