@@ -22,6 +22,7 @@
 #include <iostream> //For debug output
 #include <libgda/gda-util.h> // For gda_g_type_to_string
 #include <libglom/connectionpool.h>
+#include <libglom/utils.h>
 
 namespace Glom
 {
@@ -30,12 +31,12 @@ FieldTypes::FieldTypes(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connectio
 {
   // These are documented here:
   // http://library.gnome.org/devel/libgda-4.0/3.99/connection.html#GdaConnectionMetaTypeHead
-  enum GlomGdaDataModelTypesColumns
+  enum class GlomGdaDataModelTypesColumns
   {
-    DATAMODEL_FIELDS_COL_NAME = 0,
-    DATAMODEL_FIELDS_COL_GTYPE = 1,
-    DATAMODEL_FIELDS_COL_COMMENTS = 2,
-    DATAMODEL_FIELDS_COL_SYNONYMS = 3
+    NAME = 0,
+    GTYPE = 1,
+    COMMENTS = 2,
+    SYNONYMS = 3
   };
   
   if(gda_connection && gda_connection->is_opened())
@@ -68,7 +69,7 @@ FieldTypes::FieldTypes(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connectio
 
       for(int i = 0; i < rows; ++i)
       {
-        const auto value_name = data_model_tables->get_value_at(DATAMODEL_FIELDS_COL_NAME, i);
+        const auto value_name = data_model_tables->get_value_at(Utils::to_utype(GlomGdaDataModelTypesColumns::NAME), i);
 
         //Get the types's string representation:
         Glib::ustring schema_type_string;
@@ -77,7 +78,7 @@ FieldTypes::FieldTypes(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connectio
         
         if(!schema_type_string.empty())
         {
-          const auto value_gdatype = data_model_tables->get_value_at(DATAMODEL_FIELDS_COL_GTYPE, i);
+          const auto value_gdatype = data_model_tables->get_value_at(Utils::to_utype(GlomGdaDataModelTypesColumns::GTYPE), i);
           if(value_gdatype.get_value_type() == G_TYPE_STRING)
           {
             auto type_string = value_gdatype.get_string();
@@ -90,7 +91,7 @@ FieldTypes::FieldTypes(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connectio
            
             //std::cout << "schema type: " << schema_type_string << " = gdatype " << (guint)gdatype << "(" << gdatypestring << ")" << std::endl;
             
-            m_mapGdaTypesToSchemaStrings[gdatype] = schema_type_string; //We save it twice, to just to make searching easier, without using a predicate.
+            m_mapGdaTypesToSchemaStrings[gdatype] = schema_type_string; //We save it twice, to just to make searching easier, without using std::find.
             
             //g_warning("debug: schema type: %s = gdatype %d", schema_type_string.c_str(), gdatype);
           }
