@@ -30,36 +30,6 @@
 
 namespace Glom
 {
-  
-/** A predicate for use with std::find_if() to find a LayoutItem_Field which refers 
- * to the same field, without comparing irrelevant stuff such as formatting.
- */
-template<class T_ElementField, class T_Element = T_ElementField>
-class predicate_LayoutItem_Field_IsSameField
-{
-public:
-  predicate_LayoutItem_Field_IsSameField(const std::shared_ptr<const T_ElementField>& layout_item)
-  {
-    m_layout_item = layout_item;
-  }
-
-  bool operator() (const std::shared_ptr<const T_Element>& element)
-  {
-    if(!m_layout_item && !element)
-      return true;
-
-    //Allow this to be used on a container of LayoutItems,
-    //as well as just of LayoutItem_Fields.
-    const auto element_field = std::dynamic_pointer_cast<const T_ElementField>(element);
-    if(!element_field)
-      return false;
-       
-    return m_layout_item && m_layout_item->is_same_field(element_field);
-  }
-    
-private:
-  std::shared_ptr<const T_ElementField> m_layout_item;
-};
 
 /** A LayoutItem that shows the data from a table field.
  * The field may be in a known table, or in a to table of a relationship 
@@ -89,20 +59,20 @@ public:
 
   /** Set the non-user-visible name of the field.
    */
-  virtual void set_name(const Glib::ustring& name);
+  void set_name(const Glib::ustring& name) noexcept override;
 
   /** Get the non-user-visible name of the field.
    */
-  virtual Glib::ustring get_name() const; //For use with our std::find_if() predicate.
+  Glib::ustring get_name() const noexcept override; //For use with our std::find_if() lambda.
 
   /** Get the user-visible title for the field, in the user's current locale.
    * This returns the name if no title is set.
    */
-  virtual Glib::ustring get_title(const Glib::ustring& locale) const;
+  Glib::ustring get_title(const Glib::ustring& locale) const noexcept override;
 
   /** Get the user-visible title for the field, in the user's current locale.
    */
-  virtual Glib::ustring get_title_or_name(const Glib::ustring& locale) const;
+  Glib::ustring get_title_or_name(const Glib::ustring& locale) const noexcept override;
 
   Glib::ustring get_title_or_name_no_custom(const Glib::ustring& locale) const;
 
@@ -156,10 +126,10 @@ public:
   virtual const Formatting& get_formatting_used() const;
 
   /** Get the alignment for the formatting used (see get_formatting_used()),
-   * choosing an appropriate alignment if it is set to HORIZONTAL_ALIGNMENT_AUTO.
-   * Note that this never returns HORIZONTAL_ALIGNMENT_AUTO.
+   * choosing an appropriate alignment if it is set to HorizontalAlignment::AUTO.
+   * Note that this never returns HorizontalAlignment::AUTO.
    *
-   * @param for_details_view This can change the effect of HORIZONTAL_ALIGNMENT_AUTO.
+   * @param for_details_view This can change the effect of HorizontalAlignment::AUTO.
    */
   virtual Formatting::HorizontalAlignment get_formatting_used_horizontal_alignment(bool for_details_view = false) const;
 
@@ -189,6 +159,34 @@ private:
   std::shared_ptr<CustomTitle> m_title_custom; //translatable.
 };
 
+/**
+ * Find the element in the container which is a LayoutItem_Field which refers 
+ * to the same field, without comparing irrelevant stuff such as formatting.
+ * This assumes that the element is a shared_ptr<>.
+ */
+template
+<typename T_Container>
+auto find_if_layout_item_field_is_same_field(T_Container& container, const std::shared_ptr<const LayoutItem_Field>& layout_item) -> decltype(container.begin())
+{
+  return std::find_if(container.begin(), container.end(),
+    [&layout_item](const typename T_Container::value_type& element)
+    {
+      //Assume that element is a shared_ptr<>.
+
+      if(!layout_item && !element)
+        return true;
+
+      //Allow this to be used on a container of LayoutItems,
+      //as well as just of LayoutItem_Fields.
+      const auto element_field = std::dynamic_pointer_cast<const LayoutItem_Field>(element);
+      if(!element_field)
+        return false;
+
+      return layout_item && layout_item->is_same_field(element_field);
+    }
+  );
+}
+
 } //namespace Glom
 
 #endif //GLOM_DATASTRUCTURE_LAYOUTITEM_FIELD_H
