@@ -93,8 +93,8 @@ Glib::ustring Privs::get_default_developer_user_name(Glib::ustring& password, Do
 {
   password = "glom_default_developer_password";
 
-  if((hosting_mode == Document::HOSTING_MODE_MYSQL_CENTRAL) ||
-   (hosting_mode == Document::HOSTING_MODE_MYSQL_SELF))
+  if((hosting_mode == Document::HostingMode::MYSQL_CENTRAL) ||
+   (hosting_mode == Document::HostingMode::MYSQL_SELF))
   {
     return "glom_dev_user"; //MySQL restricts user names to 16 characters.
   }
@@ -462,7 +462,7 @@ Privileges Privs::get_current_privs(const Glib::ustring& table_name)
 
   //std::cout << "debug: " << G_STRFUNC << ": Getting non-cached." << std::endl;
 
-  ConnectionPool* connection_pool = ConnectionPool::get_instance();
+  auto connection_pool = ConnectionPool::get_instance();
   const auto current_user = connection_pool->get_user();
 
   //Is the user in the special developers group?
