@@ -83,7 +83,7 @@ static void show_gettext_error(int severity, const char* filename, const gchar*
 
     default:
     {
-      //TODO: const Glib::ustring msg = Glib::ustring(_("Gettext-Error: ")) + ' ' + msg_stream.str();
+      //TODO: const auto msg = Glib::ustring(_("Gettext-Error: ")) + ' ' + msg_stream.str();
       //Gtk::MessageDialog dlg(msg, false, Gtk::MESSAGE_ERROR);
       //dlg.run();
       break;
@@ -127,13 +127,13 @@ static void on_gettextpo_error(int status, int errnum, const char * /* format */
 }
 #endif //HAVE_GETTEXTPO_XERROR
 
-Glib::ustring get_po_context_for_item(const sharedptr<const TranslatableItem>& item, const Glib::ustring& hint)
+Glib::ustring get_po_context_for_item(const std::shared_ptr<const TranslatableItem>& item, const Glib::ustring& hint)
 {
   // Note that this context string should use English rather than the translated strings,
   // or the context would change depending on the locale of the user doing the export:
   Glib::ustring result = TranslatableItem::get_translatable_type_name_nontranslated(item->get_translatable_item_type());
 
-  const Glib::ustring name = item->get_name();
+  const auto name = item->get_name();
   if(!name.empty())
     result += " (" + item->get_name() + ')';
 
@@ -169,7 +169,7 @@ Glib::ustring get_po_context_for_item(const sharedptr<const TranslatableItem>& i
     {
       //Break after a space, if any:
       Glib::ustring part;
-      const Glib::ustring::size_type pos = remaining.find_last_of(CHAR_SPACE, MAX_WIDTH);
+      const auto pos = remaining.find_last_of(CHAR_SPACE, MAX_WIDTH);
       if(pos == Glib::ustring::npos)
         part = remaining.substr(0, MAX_WIDTH);
       else
@@ -210,17 +210,16 @@ bool write_translations_to_po_file(Document* document, const Glib::ustring& po_f
   //do that manually anyway.
   Glib::ustring data;
 
-  Document::type_list_translatables list_layout_items = document->get_translatable_items();
-  for(Document::type_list_translatables::iterator iter = list_layout_items.begin(); iter != list_layout_items.end(); ++iter)
+  for(const auto& the_pair : document->get_translatable_items())
   {
-    sharedptr<TranslatableItem> item = iter->first;
+    std::shared_ptr<TranslatableItem> item = the_pair.first;
     if(!item)
       continue;
 
     if(item->get_title_original().empty())
       continue;
 
-    const Glib::ustring hint = iter->second;
+    const Glib::ustring hint = the_pair.second;
 
     // Add "context" comments, to uniquely identify similar strings, used in different places,
     // and to provide a hint for translators.
@@ -234,9 +233,9 @@ bool write_translations_to_po_file(Document* document, const Glib::ustring& po_f
   }
 
   //The header:
-  const Glib::DateTime revision_date = Glib::DateTime::create_now_local();
-  const Glib::ustring revision_date_str = revision_date.format("%F %R%z");
-  const Glib::ustring header = Glib::ustring::compose(GLOM_PO_HEADER,
+  const auto revision_date = Glib::DateTime::create_now_local();
+  const auto revision_date_str = revision_date.format("%F %R%z");
+  const auto header = Glib::ustring::compose(GLOM_PO_HEADER,
     document->get_database_title_original(), revision_date_str, locale_name);
   
   const Glib::ustring full = header + "\n\n" + data;
@@ -259,7 +258,7 @@ bool import_translations_from_po_file(Document* document, const Glib::ustring& p
     return false;
   }
 
-  Document::type_list_translatables list_layout_items = document->get_translatable_items();
+  const auto list_layout_items = document->get_translatable_items();
   if(list_layout_items.empty())
     return false;
 
@@ -296,18 +295,18 @@ bool import_translations_from_po_file(Document* document, const Glib::ustring& p
       //This message:
       //TODO: Just use const char* instead of copying it in to a Glib::ustring,
       //if we have performance problems here:
-      const Glib::ustring msgid = Glib::convert_const_gchar_ptr_to_ustring( po_message_msgid(msg) );
-      const Glib::ustring msgstr = Glib::convert_const_gchar_ptr_to_ustring( po_message_msgstr(msg) );
-      const Glib::ustring msgcontext = Glib::convert_const_gchar_ptr_to_ustring( po_message_msgctxt(msg) );
+      const auto msgid = Glib::convert_const_gchar_ptr_to_ustring( po_message_msgid(msg) );
+      const auto msgstr = Glib::convert_const_gchar_ptr_to_ustring( po_message_msgstr(msg) );
+      const auto msgcontext = Glib::convert_const_gchar_ptr_to_ustring( po_message_msgctxt(msg) );
 
       //Find the matching item in the list:
-      for(Document::type_list_translatables::iterator iter = list_layout_items.begin(); iter != list_layout_items.end(); ++iter)
+      for(const auto& the_pair : list_layout_items)
       {
-        sharedptr<TranslatableItem> item = iter->first;
+        const auto& item = the_pair.first;
         if(!item)
           continue;
 
-        const Glib::ustring hint = iter->second;
+        const auto& hint = the_pair.second;
 
         if( (item->get_title_original() == msgid) && 
           (get_po_context_for_item(item, hint) == msgcontext) ) // This is not efficient, but it should be reliable.
