@@ -95,7 +95,7 @@ protected:
   virtual void create_layout();
 
   ///Fill the existing layout with data from the database.
-  virtual bool fill_from_database(); //override.
+  virtual bool fill_from_database() override;
 
   virtual type_vecConstLayoutFields get_fields_to_show() const;
 
@@ -104,9 +104,9 @@ protected:
   /** Get the layout groups, with the Field information filled in.
    */
   Document::type_list_layout_groups get_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& layout_platform);
-  void fill_layout_group_field_info(const sharedptr<LayoutGroup>& group, const Privileges& table_privs);
+  void fill_layout_group_field_info(const std::shared_ptr<LayoutGroup>& group, const Privileges& table_privs);
 
-  void execute_button_script(const sharedptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key_value);
+  void execute_button_script(const std::shared_ptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key_value);
 
 private:
 
