@@ -377,12 +377,12 @@ Gnome::Gda::Value Box_Data_List::get_entered_field_data(const std::shared_ptr<co
 
 void Box_Data_List::set_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
 {
-  return m_AddDel.set_value_selected(field, value);
+  m_AddDel.set_value_selected(field, value);
 }
 
 void Box_Data_List::set_entered_field_data(const Gtk::TreeModel::iterator& row, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
 {
-  return m_AddDel.set_value(row, field, value);
+  m_AddDel.set_value(row, field, value);
 }
 
 bool Box_Data_List::get_showing_multiple_records() const
