@@ -54,7 +54,7 @@ void ButtonGlom::init()
 
 AppWindow* ButtonGlom::get_appwindow() const
 {
-  Gtk::Container* pWindow = const_cast<Gtk::Container*>(get_toplevel());
+  auto pWindow = const_cast<Gtk::Container*>(get_toplevel());
   //TODO: This only works when the child widget is already in its parent.
 
   return dynamic_cast<AppWindow*>(pWindow);
@@ -84,8 +84,8 @@ void ButtonGlom::on_menu_properties_activate()
 
 bool ButtonGlom::on_button_press_event(GdkEventButton *button_event)
 {
-  AppWindow* pApp = get_appwindow();
-  if(pApp && pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
+  auto pApp = get_appwindow();
+  if(pApp && pApp->get_userlevel() == AppState::userlevels::DEVELOPER)
   {
     GdkModifierType mods;
     gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
