@@ -51,7 +51,7 @@ ComboGlom::ComboGlom(bool has_entry)
   setup_menu(this);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  //if(m_glom_type == Field::TYPE_NUMERIC)
+  //if(m_glom_type == Field::glom_field_type::NUMERIC)
    // get_entry()->set_alignment(1.0); //Align numbers to the right.
 
   //Let the combo be big enough:
@@ -134,14 +134,14 @@ void ComboGlom::set_choices_fixed(const Formatting::type_list_values& list_value
     if(i == 0 && get_has_entry())
       continue;
 
-    Gtk::CellRendererText* cell = Gtk::manage(new Gtk::CellRendererText);
+    auto cell = Gtk::manage(new Gtk::CellRendererText);
     cell->property_xalign() = 0.0f;
 
     //Use the renderer:
     cell_area->pack_start(*cell, true /* expand */, true /* align */, true /* fixed */);
 
     //Make the renderer render the column:
-    if(restricted && field && (field->get_glom_type() == Field::TYPE_TEXT))
+    if(restricted && field && (field->get_glom_type() == Field::glom_field_type::TEXT))
     {
       //Use the translation instead:
       add_attribute(*cell, "text", columns_count); //The extra text column.
@@ -207,7 +207,7 @@ void ComboGlom::set_choices_related(const Document* document, const std::shared_
       continue;
     }
 
-    Gtk::CellRenderer* cell = create_cell(layout_item, m_table_name, document, get_fixed_cell_height(*this));
+    auto cell = create_cell(layout_item, m_table_name, document, get_fixed_cell_height(*this));
 
     //Add the ViewColumn:
     if(cell)
@@ -272,13 +272,13 @@ void ComboGlom::set_value(const Gnome::Gda::Value& value)
   m_ignore_changed = old_ignore;
 
   //Show a different color if the value is numeric, if that's specified:
-  if(layout_item->get_glom_type() == Field::TYPE_NUMERIC)
+  if(layout_item->get_glom_type() == Field::glom_field_type::NUMERIC)
   {
     std::vector<Gtk::CellRenderer*> cells = get_cells();
     if(cells.empty())
       return;
 
-    Gtk::CellRendererText* cell = dynamic_cast<Gtk::CellRendererText*>(cells[0]);
+    auto cell = dynamic_cast<Gtk::CellRendererText*>(cells[0]);
     if(!cell)
       return;
 
@@ -317,7 +317,7 @@ g_warning("ComboGlom::on_button_press_event()");
 
   //Enable/Disable items.
   //We did this earlier, but get_appwindow is more likely to work now:
-  AppWindow* pApp = get_appwindow();
+  auto pApp = get_appwindow();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -329,7 +329,7 @@ g_warning("ComboGlom::on_button_press_event()");
 
     //Only show this popup in developer mode, so operators still see the default GtkEntry context menu.
     //TODO: It would be better to add it somehow to the standard context menu.
-    if(pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
+    if(pApp->get_userlevel() == AppState::userlevels::DEVELOPER)
     {
       GdkModifierType mods;
       gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
@@ -349,7 +349,7 @@ g_warning("ComboGlom::on_button_press_event()");
 
 AppWindow* ComboGlom::get_appwindow() const
 {
-  Gtk::Container* pWindow = const_cast<Gtk::Container*>(get_toplevel());
+  auto pWindow = const_cast<Gtk::Container*>(get_toplevel());
   //TODO: This only works when the child widget is already in its parent.
 
   return dynamic_cast<AppWindow*>(pWindow);
