@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_UTILITY_WIDGETS_COMBO_AS_RADIO_BUTTONS_H
@@ -52,13 +52,13 @@ public:
 
   virtual void set_choices_fixed(const Formatting::type_list_values& list_values, bool restricted = false);
 
-  virtual void set_choices_related(const Document* document, const sharedptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value);
+  virtual void set_choices_related(const Document* document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value);
 
   virtual void set_read_only(bool read_only = true);
 
   //Override this so we can store the text to compare later.
   //This is not virtual, so you must not use it via Gtk::Entry.
-  void set_text(const Glib::ustring& text); //override
+  void set_text(const Glib::ustring& text);
 
   Glib::ustring get_text() const;
 
@@ -83,12 +83,12 @@ private:
 
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual bool on_button_press_event(GdkEventButton *event);
-  virtual bool on_radiobutton_button_press_event(GdkEventButton *event);
+  virtual bool on_button_press_event(GdkEventButton *event) override;
+  bool on_radiobutton_button_press_event(GdkEventButton *event);
   void show_context_menu(GdkEventButton *event);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  virtual AppWindow* get_appwindow() const;
+  virtual AppWindow* get_appwindow() const override;
 
 
   Glib::ustring m_old_text;
