@@ -34,15 +34,15 @@ const char* Dialog_NewRecord::glade_id("dialog_new_record");
 const bool Dialog_NewRecord::glade_developer(false);
 
 Dialog_NewRecord::Dialog_NewRecord()
-: m_label_table_name(0),
-  m_vbox_parent(0)
+: m_label_table_name(nullptr),
+  m_vbox_parent(nullptr)
 {
 }
 
 Dialog_NewRecord::Dialog_NewRecord(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
-  m_label_table_name(0),
-  m_vbox_parent(0)
+  m_label_table_name(nullptr),
+  m_vbox_parent(nullptr)
 {
   builder->get_widget("label_table_name", m_label_table_name);
   builder->get_widget("vbox_parent", m_vbox_parent);
@@ -80,7 +80,7 @@ bool Dialog_NewRecord::init_db_details(const Glib::ustring& table_name, const Gl
   FoundSet found_set;
   found_set.m_table_name = m_table_name;
   const Gnome::Gda::Value primary_key_for_details;
-  const bool result = m_box_details.init_db_details(found_set, layout_platform, primary_key_for_details);
+  const auto result = m_box_details.init_db_details(found_set, layout_platform, primary_key_for_details);
   m_box_details.do_new_record();
 
   m_table_name = table_name;
