@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_MODE_DATA_DIALOG_NEW_RECORD_H
@@ -53,7 +53,7 @@ private:
   void setup();
 
   Gtk::Label* m_label_table_name;
-  Gtk::Alignment* m_alignment_parent;
+  Gtk::Box* m_vbox_parent;
 
   Glib::ustring m_table_name;
   Glib::ustring m_layout_platform;
