@@ -43,7 +43,7 @@ class TextView
 {
 public:
   explicit TextView(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
-  explicit TextView(Field::glom_field_type glom_type = Field::TYPE_TEXT);
+  explicit TextView(Field::glom_field_type glom_type = Field::glom_field_type::TEXT);
   virtual ~TextView();
 
   void set_glom_type(Field::glom_field_type glom_type);
