@@ -40,10 +40,10 @@ DbTreeModelWithExtraText::DbTreeModelWithExtraText(const FoundSet& found_set, co
 {
   //Remember the first field details so we can use it later to get a text representation.
   int column_index = 0;
-  for(type_vec_const_layout_items::const_iterator iter = layout_items.begin(); iter != layout_items.end(); ++iter)
+  for(const auto& item : layout_items)
   {
-    const sharedptr<const LayoutItem_Field> item_field = 
-      sharedptr<const LayoutItem_Field>::cast_dynamic(*iter);
+    const std::shared_ptr<const LayoutItem_Field> item_field = 
+      std::dynamic_pointer_cast<const LayoutItem_Field>(item);
     if(item_field)
     {
       m_item_first = item_field;
@@ -112,7 +112,7 @@ void DbTreeModelWithExtraText::get_value_vfunc(const TreeModel::iterator& iter,
     {
       Glib::Value<Gnome::Gda::Value> value_db;
       get_value_vfunc(iter, m_column_index_first, value_db);
-      const DbValue dbvalue = value_db.get();
+      const auto dbvalue = value_db.get();
       
       text =
         Conversions::get_text_for_gda_value(m_item_first->get_glom_type(), dbvalue, m_item_first->get_formatting_used().m_numeric_format);
