@@ -33,7 +33,7 @@ DbAddDel_WithButtons::DbAddDel_WithButtons()
   m_Button_Add(_("_Add"), true)
 {
   m_ButtonBox.set_layout(Gtk::BUTTONBOX_END);
-  m_ButtonBox.set_spacing(UiUtils::DEFAULT_SPACING_SMALL);
+  m_ButtonBox.set_spacing(Utils::to_utype(UiUtils::DefaultSpacings::SMALL));
 
   setup_buttons();
   pack_start(m_ButtonBox, Gtk::PACK_SHRINK);
@@ -102,16 +102,16 @@ void DbAddDel_WithButtons::setup_buttons()
   const auto allow_add = get_allow_user_actions() && m_allow_add;
 
   m_Button_Add.show();
-  m_Button_Add.set_property("visible", allow_add);
+  m_Button_Add.property_visible() = allow_add;
 
   m_Button_Edit.show();
-  m_Button_Edit.set_property("visible", allow_edit);
+  m_Button_Edit.property_visible() = allow_edit;
 
   if(!m_open_button_title.empty())
     m_Button_Edit.set_label(m_open_button_title);
 
   m_Button_Del.show();
-  m_Button_Del.set_property("visible", allow_del);
+  m_Button_Del.property_visible() = allow_del;
 
   m_ButtonBox.show();
 }
