@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_DB_ADDDEL_WITHBUTTONS_H
@@ -33,9 +33,9 @@ public:
   DbAddDel_WithButtons();
   virtual ~DbAddDel_WithButtons();
 
-  virtual void set_allow_add(bool val = true); //override
-  virtual void set_allow_delete(bool val = true); //override
-  virtual void set_allow_user_actions(bool bVal = true); //override
+  virtual void set_allow_add(bool val = true) override;
+  virtual void set_allow_delete(bool val = true) override;
+  virtual void set_allow_user_actions(bool bVal = true) override;
 
   ///Whether each row should have a button, to request edit.
   virtual void set_allow_view_details(bool val = true);
@@ -48,7 +48,7 @@ private:
   void on_button_edit();
   virtual void on_selection_changed(bool selection);
 
-  virtual void show_all_vfunc();
+  virtual void show_all_vfunc() override;
 
   //member widgets:
   Gtk::ButtonBox m_ButtonBox;
