@@ -49,11 +49,11 @@ void Box_DB_Table_Relationships::init()
   m_colTitle = m_AddDel.add_column(_("Title"));
 
   //Translators: FROM as in SQL's FROM
-  m_colFromField = m_AddDel.add_column(_("From Field"), AddDelColumnInfo::STYLE_Choices);
-  m_colToTable = m_AddDel.add_column(_("Table"), AddDelColumnInfo::STYLE_Choices);
-  m_colToField = m_AddDel.add_column(_("To Field"), AddDelColumnInfo::STYLE_Choices);
-  m_colAllowEdit = m_AddDel.add_column(_("Allow Editing"),  AddDelColumnInfo::STYLE_Boolean);
-  m_colAutoCreate = m_AddDel.add_column(_("Automatic Creation"),  AddDelColumnInfo::STYLE_Boolean);
+  m_colFromField = m_AddDel.add_column(_("From Field"), AddDelColumnInfo::enumStyles::Choices);
+  m_colToTable = m_AddDel.add_column(_("Table"), AddDelColumnInfo::enumStyles::Choices);
+  m_colToField = m_AddDel.add_column(_("To Field"), AddDelColumnInfo::enumStyles::Choices);
+  m_colAllowEdit = m_AddDel.add_column(_("Allow Editing"),  AddDelColumnInfo::enumStyles::Boolean);
+  m_colAutoCreate = m_AddDel.add_column(_("Automatic Creation"),  AddDelColumnInfo::enumStyles::Boolean);
 
   m_colTitleSingular = m_AddDel.add_column(_("Title (Singular Form)"));
 
@@ -77,7 +77,7 @@ bool Box_DB_Table_Relationships::fill_from_database()
 
   bool result = Box_DB_Table::fill_from_database();
 
-  const Document* document = get_document();
+  const auto document = get_document();
   if(!document)
     return false;
 
@@ -151,7 +151,7 @@ void Box_DB_Table_Relationships::save_to_document()
       if(!old_name.empty() && (old_name != name))
         get_document()->change_relationship_name(m_table_name, old_name, name); //Update layouts and reports.
 
-      if(std::find_if(vecRelationships.begin(), vecRelationships.end(), predicate_FieldHasName<Relationship>(name)) == vecRelationships.end()) //Don't add 2 relationships with the same name.
+      if(find_if_same_name(vecRelationships, name) == vecRelationships.end()) //Don't add 2 relationships with the same name.
       {
         std::shared_ptr<Relationship> relationship = document->get_relationship(m_table_name, name); //Preserve other information, such as translations.
         if(!relationship)
@@ -247,7 +247,7 @@ void Box_DB_Table_Relationships::on_adddel_user_activated(const Gtk::TreeModel::
       {
         Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
 
-        Document* document = get_document();
+        auto document = get_document();
         type_vec_strings vecFields = util_vecStrings_from_Fields(DbUtils::get_fields_for_table(document, table_name));
 
         //This would cause a lot of tedious re-filling:
@@ -278,7 +278,7 @@ void Box_DB_Table_Relationships::on_adddel_user_requested_delete(const Gtk::Tree
     m_AddDel.remove_item(iter);
 
     //Remove it from any layouts, reports, field lookups, etc:
-    Document* document = get_document();
+    auto document = get_document();
     if(document)
     {
       std::shared_ptr<const Relationship> relationship = document->get_relationship(m_table_name, relationship_name);
