@@ -32,11 +32,11 @@ const bool Dialog_AddRelatedTable::glade_developer(true);
 Dialog_AddRelatedTable::Dialog_AddRelatedTable(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
   Base_DB(),
-  m_entry_table_name(0),
-  m_entry_relationship_name(0),
-  m_combo_from_field(0),
-  m_button_edit_fields(0),
-  m_button_ok(0)
+  m_entry_table_name(nullptr),
+  m_entry_relationship_name(nullptr),
+  m_combo_from_field(nullptr),
+  m_button_edit_fields(nullptr),
+  m_button_ok(nullptr)
 {
   builder->get_widget("entry_related_table_name", m_entry_table_name);
   builder->get_widget("entry_relationship_name", m_entry_relationship_name);
@@ -69,13 +69,12 @@ void Dialog_AddRelatedTable::set_fields(const Glib::ustring& table_name)
 {
   m_table_name = table_name;
 
-  const type_vec_fields fields = DbUtils::get_fields_for_table_from_database(table_name);
+  const auto fields = DbUtils::get_fields_for_table_from_database(table_name);
 
   //Show the fields:
   m_combo_from_field->remove_all();
-  for(type_vec_fields::const_iterator iter = fields.begin(); iter != fields.end(); ++iter)
+  for(const auto& item : fields)
   {
-     sharedptr<Field> item = *iter;
      if(item)
        m_combo_from_field->append(item->get_name());
   }
@@ -84,7 +83,7 @@ void Dialog_AddRelatedTable::set_fields(const Glib::ustring& table_name)
 
 void Dialog_AddRelatedTable::on_entry_table_name()
 {
-  const Glib::ustring table_name = m_entry_table_name->get_text();
+  const auto table_name = m_entry_table_name->get_text();
   if(table_name.empty())
     return;
 
@@ -116,7 +115,7 @@ void Dialog_AddRelatedTable::on_entry_table_name()
 
 void Dialog_AddRelatedTable::on_combo_field_name()
 {
-  const Glib::ustring field_name = m_combo_from_field->get_active_text();
+  const auto field_name = m_combo_from_field->get_active_text();
   if(field_name.empty())
     return;
 
