@@ -63,7 +63,7 @@ Dialog_Database_Preferences::Dialog_Database_Preferences(BaseObjectType* cobject
   m_treeview_autoincrements->append_column(_("Field"), m_columns.m_col_field);
   const int view_cols_count = m_treeview_autoincrements->append_column(_("Next Value"), m_columns.m_col_next_value);
 
-  Gtk::CellRendererText* pCellRenderer = dynamic_cast<Gtk::CellRendererText*>(m_treeview_autoincrements->get_column_cell_renderer(view_cols_count-1));
+  auto pCellRenderer = dynamic_cast<Gtk::CellRendererText*>(m_treeview_autoincrements->get_column_cell_renderer(view_cols_count-1));
   if(pCellRenderer)
   {
     //Make it editable:
@@ -120,7 +120,7 @@ void Dialog_Database_Preferences::on_treeview_cell_edited_next_value(const Glib:
     Gtk::TreeModel::Row row = *iter;
 
     //Set it in the model:
-    long new_value = atol(new_text.c_str()); //TODO: Careful of locale.
+    const auto new_value = std::stol(new_text); //TODO: Careful of locale.
     row[m_columns.m_col_next_value] = new_value;
 
 
@@ -197,11 +197,11 @@ void Dialog_Database_Preferences::load_from_document()
   {
     auto iter = m_model_autoincrements->append();
     Gtk::TreeModel::Row row = *iter;
-    row[m_columns.m_col_table] = Conversions::get_text_for_gda_value(Field::TYPE_TEXT, datamodel->get_value_at(0, i), numeric_format);
-    row[m_columns.m_col_field] = Conversions::get_text_for_gda_value(Field::TYPE_TEXT, datamodel->get_value_at(1, i), numeric_format);
+    row[m_columns.m_col_table] = Conversions::get_text_for_gda_value(Field::glom_field_type::TEXT, datamodel->get_value_at(0, i), numeric_format);
+    row[m_columns.m_col_field] = Conversions::get_text_for_gda_value(Field::glom_field_type::TEXT, datamodel->get_value_at(1, i), numeric_format);
 
     //TODO: Careful of locale:
-    row[m_columns.m_col_next_value] = atol(datamodel->get_value_at(2, i).to_string().c_str());
+    row[m_columns.m_col_next_value] = std::stol(datamodel->get_value_at(2, i).to_string());
   }
 
   m_model_autoincrements->set_default_sort_func( sigc::mem_fun(*this, &Dialog_Database_Preferences::on_autoincrements_sort) );
@@ -230,12 +230,12 @@ void Dialog_Database_Preferences::save_to_document()
   m_glade_variables_map.transfer_widgets_to_variables();
   m_system_prefs.m_org_logo = m_image->get_value();
 
-  Document* document = get_document();
+  auto document = get_document();
   if(!document)
      return;
 
   //Make sure that set_database_preferences() can work.
-  if(get_userlevel() == AppState::USERLEVEL_DEVELOPER)
+  if(get_userlevel() == AppState::userlevels::DEVELOPER)
     DbUtils::add_standard_tables(document);
 
   DbUtils::set_database_preferences(document, m_system_prefs);
@@ -264,7 +264,7 @@ void Dialog_Database_Preferences::on_button_test_script()
 
   type_map_fields field_values;
 
-  Document* document = get_document();
+  auto document = get_document();
   if(!document)
     return;
 
