@@ -196,7 +196,7 @@ void ComboBox_Fields::on_cell_data_title(const Gtk::TreeModel::const_iterator& i
   std::shared_ptr<Field> field = row[m_model_columns.m_field];
   if(field)
   {
-    m_renderer_title->set_property("text", item_get_title_or_name(field));
+    m_renderer_title->property_text() = item_get_title_or_name(field);
   }
   else
   {
@@ -207,7 +207,7 @@ void ComboBox_Fields::on_cell_data_title(const Gtk::TreeModel::const_iterator& i
     //otherwise we get this warning:
     //" unable to set property `text' of type `gchararray' from value of type `glibmm__CustomPointer_Pc' "
     //TODO: Add a template specialization to Glib::ObjectBase::set_property() to allow this?
-    m_renderer_title->set_property("text", Glib::ustring(_("(None)")));
+    m_renderer_title->property_text() = Glib::ustring(_("(None)"));
   }
 }
 
