@@ -110,15 +110,15 @@ Box_Formatting::Box_Formatting(BaseObjectType* cobject, const Glib::RefPtr<Gtk::
   m_model_alignment = Gtk::ListStore::create(m_columns_alignment);
 
   auto iter = m_model_alignment->append();
-  (*iter)[m_columns_alignment.m_col_alignment] = Formatting::HORIZONTAL_ALIGNMENT_AUTO;
+  (*iter)[m_columns_alignment.m_col_alignment] = Formatting::HorizontalAlignment::AUTO;
   //Translators: This is Automatic text alignment.
   (*iter)[m_columns_alignment.m_col_title] = _("Automatic");
   iter = m_model_alignment->append();
-  (*iter)[m_columns_alignment.m_col_alignment] = Formatting::HORIZONTAL_ALIGNMENT_LEFT;
+  (*iter)[m_columns_alignment.m_col_alignment] = Formatting::HorizontalAlignment::LEFT;
   //Translators: This is Left text alignment.
   (*iter)[m_columns_alignment.m_col_title] = _("Left");
   iter = m_model_alignment->append();
-  (*iter)[m_columns_alignment.m_col_alignment] = Formatting::HORIZONTAL_ALIGNMENT_RIGHT;
+  (*iter)[m_columns_alignment.m_col_alignment] = Formatting::HorizontalAlignment::RIGHT;
   //Translators: This is Right text alignment.
   (*iter)[m_columns_alignment.m_col_title] = _("Right");
 
@@ -198,7 +198,7 @@ void Box_Formatting::set_is_for_non_editable()
   m_show_editable_options = false;
 
   //Add labels (because we will hide the checkboxes):
-  Gtk::Label* label = Gtk::manage(new Gtk::Label(_("Font")));
+  auto label = Gtk::manage(new Gtk::Label(_("Font")));
   label->show();
   m_hbox_font->pack_start(*label, Gtk::PACK_SHRINK);
   label = Gtk::manage(new Gtk::Label(_("Foreground Color")));
@@ -351,7 +351,7 @@ bool Box_Formatting::get_formatting(Formatting& format) const
   m_format.m_numeric_format.m_decimal_places_restricted = m_checkbox_format_use_decimal_places->get_active();
 
   const auto strDecPlaces = m_entry_format_decimal_places->get_text();
-  m_format.m_numeric_format.m_decimal_places = atoi(strDecPlaces.c_str());
+  m_format.m_numeric_format.m_decimal_places = std::stoi(strDecPlaces);
 
   m_format.m_numeric_format.m_currency_symbol = m_entry_currency_symbol->get_entry()->get_text();
 
@@ -360,7 +360,7 @@ bool Box_Formatting::get_formatting(Formatting& format) const
 
   //Text formatting:
   auto iter = m_combo_format_text_horizontal_alignment->get_active();
-  Formatting::HorizontalAlignment alignment = Formatting::HORIZONTAL_ALIGNMENT_LEFT;
+  Formatting::HorizontalAlignment alignment = Formatting::HorizontalAlignment::LEFT;
   if(iter)
     alignment = (*iter)[m_columns_alignment.m_col_alignment];
   m_format.set_horizontal_alignment(alignment);
@@ -441,7 +441,7 @@ void Box_Formatting::on_combo_choices_relationship_changed()
 {
   std::shared_ptr<Relationship> relationship = m_combo_choices_relationship->get_selected_relationship();
 
-  Document* pDocument = get_document();
+  auto pDocument = get_document();
   if(pDocument)
   {
     //Show the list of fields from this relationship:
@@ -490,10 +490,10 @@ void Box_Formatting::enforce_constraints()
   if(m_field)
   {
     m_show_numeric = false;
-    if(m_field->get_glom_type() == Field::TYPE_NUMERIC)
+    if(m_field->get_glom_type() == Field::glom_field_type::NUMERIC)
       m_show_numeric = true;
 
-    if((m_field->get_glom_type() == Field::TYPE_BOOLEAN) || (m_field->get_glom_type() == Field::TYPE_IMAGE)) //TODO: Allow text options when showing booleans as Yes/No on print layouts.
+    if((m_field->get_glom_type() == Field::glom_field_type::BOOLEAN) || (m_field->get_glom_type() == Field::glom_field_type::IMAGE)) //TODO: Allow text options when showing booleans as Yes/No on print layouts.
     {
       show_text = false;
     }
@@ -504,7 +504,7 @@ void Box_Formatting::enforce_constraints()
     m_vbox_text_format->show();
 
     //Hide multiline options for non-text fields:
-    if(m_for_print_layout || !m_field || (m_field->get_glom_type() != Field::TYPE_TEXT))
+    if(m_for_print_layout || !m_field || (m_field->get_glom_type() != Field::glom_field_type::TEXT))
     {
       m_checkbox_format_text_multiline->hide();
       m_label_format_text_multiline_height->hide();
