@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_LAYOUT_ITEM_DIALOGS_FIELD_SUMMARY_H
@@ -48,10 +48,10 @@ public:
    * @param item The starting information.
    * @param table_name The item's table.
    */
-  virtual void set_item(const sharedptr<const LayoutItem_FieldSummary>& item, const Glib::ustring& table_name);
+  virtual void set_item(const std::shared_ptr<const LayoutItem_FieldSummary>& item, const Glib::ustring& table_name);
 
 
-  sharedptr<LayoutItem_FieldSummary> get_item() const;
+  std::shared_ptr<LayoutItem_FieldSummary> get_item() const;
 
 private:
   //Signal handlers:
@@ -61,7 +61,7 @@ private:
   Combo_SummaryType* m_combo_summarytype;
   Gtk::Button* m_button_field;
 
-  mutable sharedptr<LayoutItem_FieldSummary> m_layout_item;
+  mutable std::shared_ptr<LayoutItem_FieldSummary> m_layout_item;
 
   Glib::ustring m_table_name;
 };
