@@ -27,7 +27,7 @@ namespace Glom
 {
 
 Dialog_Formatting::Dialog_Formatting()
-: m_box_formatting(0)
+: m_box_formatting(nullptr)
 {
   set_title(_("Formatting"));
   set_border_width(6);
@@ -47,14 +47,14 @@ Dialog_Formatting::~Dialog_Formatting()
   remove_view(m_box_formatting);
 }
 
-void Dialog_Formatting::set_item(const sharedptr<const LayoutItem_WithFormatting>& layout_item, bool show_numeric)
+void Dialog_Formatting::set_item(const std::shared_ptr<const LayoutItem_WithFormatting>& layout_item, bool show_numeric)
 {
   m_box_formatting->set_formatting_for_non_field(layout_item->m_formatting, show_numeric);
 
   enforce_constraints();
 }
 
-void Dialog_Formatting::use_item_chosen(const sharedptr<LayoutItem_WithFormatting>& layout_item)
+void Dialog_Formatting::use_item_chosen(const std::shared_ptr<LayoutItem_WithFormatting>& layout_item)
 {
   if(!layout_item)
     return;
