@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_MODE_DESIGN_DIALOG_TEXTOBJECT_H
@@ -43,16 +43,16 @@ public:
   Dialog_TextObject(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_TextObject();
 
-  void set_textobject(const sharedptr<const LayoutItem_Text>& textobject, const Glib::ustring& table_name, bool show_title = true);
-  sharedptr<LayoutItem_Text> get_textobject() const;
-  void get_textobject(sharedptr<LayoutItem_Text>& textobject) const;
+  void set_textobject(const std::shared_ptr<const LayoutItem_Text>& textobject, const Glib::ustring& table_name, bool show_title = true);
+  std::shared_ptr<LayoutItem_Text> get_textobject() const;
+  void get_textobject(std::shared_ptr<LayoutItem_Text>& textobject) const;
 
 private:
   Gtk::Box* m_box_title;
   Gtk::Entry* m_entry_title;
   Gtk::TextView* m_text_view;
 
-  sharedptr<LayoutItem_Text> m_textobject;
+  std::shared_ptr<LayoutItem_Text> m_textobject;
   Glib::ustring m_table_name;
 };
 
