@@ -30,11 +30,11 @@ const bool Dialog_ChangeLanguage::glade_developer(true);
 
 Dialog_ChangeLanguage::Dialog_ChangeLanguage(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
-  m_combo_locale(0)
+  m_combo_locale(nullptr)
 {
   builder->get_widget_derived("combobox_locale", m_combo_locale);
-
-  m_combo_locale->set_selected_locale(AppWindow::get_current_locale());
+  if(m_combo_locale)
+    m_combo_locale->set_selected_locale(AppWindow::get_current_locale());
 }
 
 Dialog_ChangeLanguage::~Dialog_ChangeLanguage()
