@@ -28,7 +28,7 @@ const bool Dialog_ChooseUser::glade_developer(true);
 
 Dialog_ChooseUser::Dialog_ChooseUser(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
-  m_combo_name(0)
+  m_combo_name(nullptr)
 {
   builder->get_widget_derived("combo_user_name", m_combo_name);
 }
@@ -39,9 +39,9 @@ Dialog_ChooseUser::~Dialog_ChooseUser()
 
 void Dialog_ChooseUser::set_user_list(const type_vec_strings& users)
 {
-  for(type_vec_strings::const_iterator iter = users.begin(); iter != users.end(); ++iter)
+  for(const auto& item : users)
   {
-    m_combo_name->append(*iter);
+    m_combo_name->append(item);
   }
 
   m_combo_name->set_first_active();
