@@ -62,8 +62,8 @@ Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr
   // Append the View columns:
 
   //Groups:
-  Gtk::CellRendererText* pCell = Gtk::manage(new Gtk::CellRendererText);
-  Gtk::TreeView::Column* pViewColumn = Gtk::manage(new Gtk::TreeView::Column(_("Name"), *pCell) );
+  auto pCell = Gtk::manage(new Gtk::CellRendererText);
+  auto pViewColumn = Gtk::manage(new Gtk::TreeView::Column(_("Name"), *pCell) );
   pViewColumn->set_cell_data_func(*pCell, sigc::mem_fun(*this, &Dialog_GroupsList::on_cell_data_group_name));
   m_treeview_groups->append_column(*pViewColumn);
 
@@ -383,7 +383,7 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
   //Fill the model rows:
   m_model_tables->clear();
 
- Document* pDocument = get_document();
+ auto pDocument = get_document();
   if(pDocument)
   {
     // Make sure that these are in the document,
@@ -428,12 +428,12 @@ void Dialog_GroupsList::load_from_document()
 
 void Dialog_GroupsList::treeview_append_bool_column(Gtk::TreeView& treeview, const Glib::ustring& title, Gtk::TreeModelColumn<bool>& model_column, const sigc::slot<void,  const Glib::ustring&>& slot_toggled)
 {
-  Gtk::CellRendererToggle* pCellRenderer = Gtk::manage( new Gtk::CellRendererToggle() );
+  auto pCellRenderer = Gtk::manage( new Gtk::CellRendererToggle() );
 
   //GTK+'s "activatable" really means "editable":
   pCellRenderer->property_activatable() = true;
 
-  Gtk::TreeView::Column* pViewColumn = Gtk::manage( new Gtk::TreeView::Column(title, *pCellRenderer) );
+  auto pViewColumn = Gtk::manage( new Gtk::TreeView::Column(title, *pCellRenderer) );
   pViewColumn->set_renderer(*pCellRenderer, model_column); //render it via the default "text" property.
 
   treeview.append_column(*pViewColumn);
@@ -463,13 +463,13 @@ bool Dialog_GroupsList::set_table_privilege(const Glib::ustring& table_name, con
 
   //What to grant or revoke:
   Glib::ustring strPrivilege;
-  if(priv == PRIV_VIEW)
+  if(priv == enumPriv::VIEW)
     strPrivilege = "SELECT";
-  else if(priv == PRIV_EDIT)
+  else if(priv == enumPriv::EDIT)
     strPrivilege = "UPDATE";
-  else if(priv == PRIV_CREATE)
+  else if(priv == enumPriv::CREATE)
     strPrivilege = "INSERT";
-  else if(priv == PRIV_DELETE)
+  else if(priv == enumPriv::DELETE)
     strPrivilege = "DELETE";
 
   strQuery += " " + strPrivilege + " ON " + DbUtils::escape_sql_id(table_name) + " ";
@@ -506,19 +506,19 @@ void Dialog_GroupsList::on_treeview_tables_toggled_view(const Glib::ustring& pat
     const auto group_name = get_selected_group();
     const Glib::ustring table_name = row[m_model_columns_tables.m_col_name];
 
-    if(set_table_privilege(table_name, group_name, bActive, PRIV_VIEW))
+    if(set_table_privilege(table_name, group_name, bActive, enumPriv::VIEW))
       row[m_model_columns_tables.m_col_view] = bActive;
 
     //If the group cannot view, then it should not do anything else either:
     if(!bActive)
     {
-     if(set_table_privilege(table_name, group_name, bActive, PRIV_EDIT))
+     if(set_table_privilege(table_name, group_name, bActive, enumPriv::EDIT))
         row[m_model_columns_tables.m_col_edit] = false;
 
-      if(set_table_privilege(table_name, group_name, bActive, PRIV_CREATE))
+      if(set_table_privilege(table_name, group_name, bActive, enumPriv::CREATE))
         row[m_model_columns_tables.m_col_create] = false;
 
-      if(set_table_privilege(table_name, group_name, bActive, PRIV_DELETE))
+      if(set_table_privilege(table_name, group_name, bActive, enumPriv::DELETE))
         row[m_model_columns_tables.m_col_delete] = false;
     }
   }
@@ -541,7 +541,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_edit(const Glib::ustring& pat
     const auto group_name = get_selected_group();
     const Glib::ustring table_name = row[m_model_columns_tables.m_col_name];
 
-    bool test = set_table_privilege(table_name, group_name, bActive, PRIV_EDIT);
+    bool test = set_table_privilege(table_name, group_name, bActive, enumPriv::EDIT);
 
     if(test)
       row[m_model_columns_tables.m_col_edit] = bActive;
@@ -565,7 +565,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_create(const Glib::ustring& p
     const auto group_name = get_selected_group();
     const Glib::ustring table_name = row[m_model_columns_tables.m_col_name];
 
-    const auto test = set_table_privilege(table_name, group_name, bActive, PRIV_CREATE);
+    const auto test = set_table_privilege(table_name, group_name, bActive, enumPriv::CREATE);
 
     if(test)
       row[m_model_columns_tables.m_col_create] = bActive;
@@ -589,7 +589,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_delete(const Glib::ustring& p
     const auto group_name = get_selected_group();
     const Glib::ustring table_name = row[m_model_columns_tables.m_col_name];
 
-    const auto test = set_table_privilege(table_name, group_name, bActive, PRIV_DELETE);
+    const auto test = set_table_privilege(table_name, group_name, bActive, enumPriv::DELETE);
 
     if(test)
       row[m_model_columns_tables.m_col_delete] = bActive;
@@ -599,7 +599,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_delete(const Glib::ustring& p
 void Dialog_GroupsList::on_cell_data_group_name(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
 {
  //Set the view's cell properties depending on the model's data:
-  Gtk::CellRendererText* renderer_text = dynamic_cast<Gtk::CellRendererText*>(renderer);
+  auto renderer_text = dynamic_cast<Gtk::CellRendererText*>(renderer);
   if(renderer_text)
   {
     if(iter)
