@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_BOX_DATA_DETAILS_FIND_H
@@ -34,14 +34,14 @@ public:
 
   bool init_db_details(const Glib::ustring& table_name, const Glib::ustring& layout_platform);
 
-  virtual Gtk::Widget* get_default_button(); //override
+  virtual Gtk::Widget* get_default_button() override;
 
 private:
 
-  virtual bool fill_from_database(); //override.
-  virtual void fill_related(); //override.
+  virtual bool fill_from_database() override;
+  void fill_related();
 
-  virtual void on_flowtable_field_edited(const sharedptr<const LayoutItem_Field>& id, const Gnome::Gda::Value& value);
+  virtual void on_flowtable_field_edited(const std::shared_ptr<const LayoutItem_Field>& id, const Gnome::Gda::Value& value);
 
 };
 
