@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef BOX_TABLES_H
@@ -25,6 +25,7 @@
 #include <glom/base_db.h>
 #include <glom/utility_widgets/adddel/adddel_withbuttons.h>
 #include <gtkmm/builder.h>
+#include <gtkmm/checkbutton.h>
 
 namespace Glom
 {
@@ -45,9 +46,9 @@ public:
   virtual ~Box_Tables();
 
 private:
-  bool fill_from_database(); //override
+  bool fill_from_database() override;
 
-  void fill_table_row(const Gtk::TreeModel::iterator& iter, const sharedptr<const TableInfo>& table_info);
+  void fill_table_row(const Gtk::TreeModel::iterator& iter, const std::shared_ptr<const TableInfo>& table_info);
 
   //Signal handlers:
 #ifndef GLOM_ENABLE_CLIENT_ONLY
