@@ -43,7 +43,7 @@ double get_page_height(const Glib::RefPtr<const Gtk::PageSetup>& page_setup, Gtk
   margin_top = 0;
   margin_bottom = 0;
 
-  const Gtk::PaperSize paper_size = page_setup->get_paper_size();
+  const auto paper_size = page_setup->get_paper_size();
   
   double page_height = 0;
   if(page_setup->get_orientation() == Gtk::PAGE_ORIENTATION_PORTRAIT) //TODO: Handle the reverse orientations too?
@@ -69,11 +69,11 @@ static void get_page_y_start_and_end(const Glib::RefPtr<const Gtk::PageSetup>& p
   y1 = 0;
   y2 = 0;
   
-  const Gtk::PaperSize paper_size = page_setup->get_paper_size();
+  const auto paper_size = page_setup->get_paper_size();
   
   double margin_top = 0;
   double margin_bottom = 0;
-  const double page_height = get_page_height(page_setup, units, 
+  const auto page_height = get_page_height(page_setup, units, 
     margin_top, margin_bottom);
     
   //y1:
@@ -93,9 +93,9 @@ double get_offset_to_move_fully_to_next_page(const Glib::RefPtr<const Gtk::PageS
 {
   double top_margin = 0;
   double bottom_margin = 0;
-  const double page_height = get_page_height(page_setup, units, top_margin, bottom_margin);
+  const auto page_height = get_page_height(page_setup, units, top_margin, bottom_margin);
 
-  const guint current_page = PrintLayoutUtils::get_page_for_y(page_setup, units, y);
+  const auto current_page = PrintLayoutUtils::get_page_for_y(page_setup, units, y);
   const double usable_page_start = current_page * page_height + top_margin + GRID_GAP;
   //std::cout << G_STRFUNC << ": debug: current_page=" << current_page << ", usable_page_start =" << usable_page_start << std::endl;
 
@@ -119,7 +119,7 @@ static double move_fully_to_page(const Glib::RefPtr<const Gtk::PageSetup>& page_
 {
   double top_margin = 0;
   double bottom_margin = 0;
-  const double page_height = get_page_height(page_setup, units, top_margin, bottom_margin);
+  const auto page_height = get_page_height(page_setup, units, top_margin, bottom_margin);
 
   //Ignore items that would not overlap even if they had the same y:
   //Note that we try to keep an extra GRID_GAP from the edge of the margin:
@@ -127,7 +127,7 @@ static double move_fully_to_page(const Glib::RefPtr<const Gtk::PageSetup>& page_
   if(height > usable_page_height)
     return y; //It will always be in a margin because it is so big. We could never move it somewhere where it would not be.
 
-  const double offset = get_offset_to_move_fully_to_next_page(page_setup, units, y, height);
+  const auto offset = get_offset_to_move_fully_to_next_page(page_setup, units, y, height);
   return y + offset;
 }
 
@@ -144,7 +144,7 @@ bool needs_move_fully_to_page(const Glib::RefPtr<const Gtk::PageSetup>& page_set
   //We don't actually move it, because items would then group together 
   //at the top of pages.
   //Instead, the caller will discover an offset to apply to all items:
-  const double y_new = move_fully_to_page(page_setup, units, y, height);
+  const auto y_new = move_fully_to_page(page_setup, units, y, height);
   if(y_new != y)
     return true;
 
@@ -152,7 +152,7 @@ bool needs_move_fully_to_page(const Glib::RefPtr<const Gtk::PageSetup>& page_set
 }
 
 /*
-static double move_fully_to_page(const Glib::RefPtr<const Gtk::PageSetup>& page_setup, Gtk::Unit units, const sharedptr<LayoutItem>& item)
+static double move_fully_to_page(const Glib::RefPtr<const Gtk::PageSetup>& page_setup, Gtk::Unit units, const std::shared_ptr<LayoutItem>& item)
 {
   double x = 0;
   double y = 0;
@@ -160,7 +160,7 @@ static double move_fully_to_page(const Glib::RefPtr<const Gtk::PageSetup>& page_
   double height = 0;
   item->get_print_layout_position(x, y, width, height);
   
-  const double y_new = move_fully_to_page(page_setup, units, y, height);
+  const auto y_new = move_fully_to_page(page_setup, units, y, height);
   if(y_new != y)
     item->set_print_layout_position(x, y_new, width, height);
     
@@ -168,7 +168,7 @@ static double move_fully_to_page(const Glib::RefPtr<const Gtk::PageSetup>& page_
 }
 */
 
-static void create_standard(const sharedptr<const LayoutGroup>& layout_group, const sharedptr<LayoutGroup>& print_layout_group, const Glib::RefPtr<const Gtk::PageSetup>& page_setup, Gtk::Unit units, double x, double& y, bool avoid_page_margins)
+static void create_standard(const std::shared_ptr<const LayoutGroup>& layout_group, const std::shared_ptr<LayoutGroup>& print_layout_group, const Glib::RefPtr<const Gtk::PageSetup>& page_setup, Gtk::Unit units, double x, double& y, bool avoid_page_margins)
 {
   if(!layout_group || !print_layout_group)
   {
@@ -177,17 +177,17 @@ static void create_standard(const sharedptr<const LayoutGroup>& layout_group, co
 
   const double gap = GRID_GAP;
 
-  const Gtk::PaperSize paper_size = page_setup->get_paper_size();
-  const double item_width = paper_size.get_width(units) - x -
+  const auto paper_size = page_setup->get_paper_size();
+  const auto item_width = paper_size.get_width(units) - x -
     page_setup->get_right_margin(units) - gap;
   const double field_height = ITEM_HEIGHT;
 
   //Show the group's title
   //(but do not fall back to the name, because unnamed groups are really wanted sometimes.)
-  const Glib::ustring title = item_get_title(layout_group);
+  const auto title = item_get_title(layout_group);
   if(!title.empty())
   {
-    sharedptr<LayoutItem_Text> text = sharedptr<LayoutItem_Text>::create();
+    std::shared_ptr<LayoutItem_Text> text = std::make_shared<LayoutItem_Text>();
     text->set_text(title, AppWindow::get_current_locale());
     text->m_formatting.set_text_format_font("Sans Bold 10");
 
@@ -201,10 +201,10 @@ static void create_standard(const sharedptr<const LayoutGroup>& layout_group, co
   }
 
   //Deal with a portal group: 
-  const sharedptr<const LayoutItem_Portal> portal = sharedptr<const LayoutItem_Portal>::cast_dynamic(layout_group); 
+  const std::shared_ptr<const LayoutItem_Portal> portal = std::dynamic_pointer_cast<const LayoutItem_Portal>(layout_group); 
   if(portal)
   {
-    sharedptr<LayoutItem_Portal> portal_clone = glom_sharedptr_clone(portal);
+    std::shared_ptr<LayoutItem_Portal> portal_clone = glom_sharedptr_clone(portal);
     portal_clone->set_print_layout_row_height(field_height); //Otherwise it will be 0, which is useless.
 
     //We ignore the rows count for the details layout's portal,
@@ -227,13 +227,12 @@ static void create_standard(const sharedptr<const LayoutGroup>& layout_group, co
 
   //Deal with a regular group:
   //Recurse into the group's child items:
-  for(LayoutGroup::type_list_items::const_iterator iter = layout_group->m_list_items.begin(); iter != layout_group->m_list_items.end(); ++iter)
+  for(const auto& item : layout_group->m_list_items)
   {
-    const sharedptr<const LayoutItem> item = *iter;
     if(!item)
       continue;
 
-    const sharedptr<const LayoutGroup> group = sharedptr<const LayoutGroup>::cast_dynamic(item);
+    const std::shared_ptr<const LayoutGroup> group = std::dynamic_pointer_cast<const LayoutGroup>(item);
     if(group && !portal)
     {
       //Recurse:
@@ -242,13 +241,13 @@ static void create_standard(const sharedptr<const LayoutGroup>& layout_group, co
     else
     {
       //Add field titles, if necessary:
-      sharedptr<LayoutItem_Text> text_title;
+      std::shared_ptr<LayoutItem_Text> text_title;
       const double title_width = ITEM_WIDTH_WIDE; //TODO: Calculate it based on the widest in the column. Or just halve the column to start.
-      const sharedptr<const LayoutItem_Field> field = sharedptr<const LayoutItem_Field>::cast_dynamic(item);
+      const std::shared_ptr<const LayoutItem_Field> field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
       if(field)
       {
-        text_title = sharedptr<LayoutItem_Text>::create();
-        const Glib::ustring field_title = item_get_title_or_name(field);
+        text_title = std::make_shared<LayoutItem_Text>();
+        const auto field_title = item_get_title_or_name(field);
         text_title->set_text(field_title + ":", AppWindow::get_current_locale());
         
         if(avoid_page_margins)
@@ -261,7 +260,7 @@ static void create_standard(const sharedptr<const LayoutGroup>& layout_group, co
       }
 
       //Add the item, such as a field:
-      sharedptr<LayoutItem> clone = glom_sharedptr_clone(item);
+      std::shared_ptr<LayoutItem> clone = glom_sharedptr_clone(item);
 
       double item_x = x;
       if(field)
@@ -274,10 +273,10 @@ static void create_standard(const sharedptr<const LayoutGroup>& layout_group, co
       double this_field_height = field_height;
       if(field)
       {
-        const Formatting& formatting = field->get_formatting_used();
+        const auto formatting = field->get_formatting_used();
         if(formatting.get_text_format_multiline())
         {
-          const guint lines = formatting.get_text_format_multiline_height_lines();
+          const auto lines = formatting.get_text_format_multiline_height_lines();
           if(lines)
             this_field_height = field_height * lines;
         }
@@ -301,7 +300,7 @@ static void create_standard(const sharedptr<const LayoutGroup>& layout_group, co
 
 guint get_page_for_y(const Glib::RefPtr<const Gtk::PageSetup>& page_setup, Gtk::Unit units, double y)
 {
-  const double page_height = get_page_height(page_setup, units);
+  const auto page_height = get_page_height(page_setup, units);
   if(!page_height)
     return 0; //Avoid a division by zero.
 
@@ -311,10 +310,10 @@ guint get_page_for_y(const Glib::RefPtr<const Gtk::PageSetup>& page_setup, Gtk::
   return pages_integral;
 }
 
-sharedptr<PrintLayout> create_standard(const Glib::RefPtr<const Gtk::PageSetup>& page_setup, const Glib::ustring& table_name, const Document* document, bool avoid_page_margins)
+std::shared_ptr<PrintLayout> create_standard(const Glib::RefPtr<const Gtk::PageSetup>& page_setup, const Glib::ustring& table_name, const Document* document, bool avoid_page_margins)
 {
   const Gtk::Unit units = Gtk::UNIT_MM;
-  sharedptr<PrintLayout> print_layout = sharedptr<PrintLayout>::create();  
+  std::shared_ptr<PrintLayout> print_layout = std::make_shared<PrintLayout>();  
   
   //Start inside the border, on the next grid line:
   double y = 0;
@@ -329,10 +328,10 @@ sharedptr<PrintLayout> create_standard(const Glib::RefPtr<const Gtk::PageSetup>&
     x += GRID_GAP;
   
   //The table title:
-  const Glib::ustring title = document->get_table_title_singular(table_name, AppWindow::get_current_locale());
+  const auto title = document->get_table_title_singular(table_name, AppWindow::get_current_locale());
   if(!title.empty())
   {
-    sharedptr<LayoutItem_Text> text = sharedptr<LayoutItem_Text>::create();
+    std::shared_ptr<LayoutItem_Text> text = std::make_shared<LayoutItem_Text>();
     text->set_text(title, AppWindow::get_current_locale());
     text->m_formatting.set_text_format_font("Sans Bold 12");
 
@@ -345,11 +344,8 @@ sharedptr<PrintLayout> create_standard(const Glib::RefPtr<const Gtk::PageSetup>&
 
   //The layout:
   //TODO: Use fill_layout_group_field_info()?
-  const Document::type_list_layout_groups layout_groups = 
-    document->get_data_layout_groups("details", table_name); //TODO: layout_platform.
-  for(Document::type_list_layout_groups::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
+  for(const auto& group : document->get_data_layout_groups("details", table_name)) //TODO: layout_platform.
   {
-    const sharedptr<const LayoutGroup> group = *iter;
     if(!group)
       continue;
 
@@ -360,7 +356,7 @@ sharedptr<PrintLayout> create_standard(const Glib::RefPtr<const Gtk::PageSetup>&
   //y is probably _after_ the last item, not exactly at the bottom of the last item, so we subtract gap.
   //TODO: However, this might not be reliable,
   //so this could lead to an extra blank page.
-  const guint page_number = get_page_for_y(page_setup, units, y - GRID_GAP);
+  const auto page_number = get_page_for_y(page_setup, units, y - GRID_GAP);
   if(page_number >= print_layout->get_page_count())
   {
     print_layout->set_page_count(page_number + 1);
@@ -369,7 +365,7 @@ sharedptr<PrintLayout> create_standard(const Glib::RefPtr<const Gtk::PageSetup>&
   return print_layout;
 }
 
-void do_print_layout(const sharedptr<const PrintLayout>& print_layout, const FoundSet& found_set, bool preview, const Document* document, bool avoid_page_margins, Gtk::Window* transient_for)
+void do_print_layout(const std::shared_ptr<const PrintLayout>& print_layout, const FoundSet& found_set, bool preview, const Document* document, bool avoid_page_margins, Gtk::Window* transient_for)
 {
   if(!print_layout)
   {
@@ -394,7 +390,7 @@ void do_print_layout(const sharedptr<const PrintLayout>& print_layout, const Fou
   canvas.set_document(const_cast<Document*>(document)); //We const_cast because, for this use, it will not be changed.
 
   //We cast to unconst because we know that the layout will not be changed by this use: 
-  sharedptr<PrintLayout> unconst = sharedptr<PrintLayout>::cast_const(print_layout);
+  std::shared_ptr<PrintLayout> unconst = std::const_pointer_cast<PrintLayout>(print_layout);
   canvas.set_print_layout(found_set.m_table_name, unconst);
 
   //Do not show things that are only for editing the print layout:
@@ -411,7 +407,7 @@ void do_print_layout(const sharedptr<const PrintLayout>& print_layout, const Fou
 
   //TODO: Put this in a utility function.
   Glib::RefPtr<Gtk::PageSetup> page_setup;
-  const Glib::ustring key_file_text = print_layout->get_page_setup();
+  const auto key_file_text = print_layout->get_page_setup();
   if(!key_file_text.empty())
   {
     Glib::KeyFile key_file;
