@@ -62,8 +62,8 @@ void CanvasEditable::add_item(const Glib::RefPtr<Goocanvas::Item>& item, const G
     Glib::RefPtr<CanvasItemMovable> movable = Glib::RefPtr<CanvasItemMovable>::cast_dynamic(item);
     if(movable)
     {
-      Glib::RefPtr<CanvasGroupResizable> resizable = CanvasGroupResizable::create();
-      resizable->set_grid(m_grid);
+      Glib::RefPtr<CanvasGroupResizable> resizable_item = CanvasGroupResizable::create();
+      resizable_item->set_grid(m_grid);
 
       //Specify the resizable's position, using the child's position:
       double x = 0;
@@ -72,11 +72,11 @@ void CanvasEditable::add_item(const Glib::RefPtr<Goocanvas::Item>& item, const G
       double width = 0;
       double height = 0;
       movable->get_width_height(width, height);
-      resizable->set_xy(x, y);
-      resizable->set_width_height(width, height);
+      resizable_item->set_xy(x, y);
+      resizable_item->set_width_height(width, height);
 
-      group->add_child(resizable);
-      resizable->set_child(movable); //Puts draggable corners and edges around it.
+      group->add_child(resizable_item);
+      resizable_item->set_child(movable); //Puts draggable corners and edges around it.
 
       added = true;
     }
@@ -113,7 +113,7 @@ void CanvasEditable::remove_item(const Glib::RefPtr<Goocanvas::Item>& item , con
 
 void CanvasEditable::remove_all_items()
 {
-  const bool some_selected = !(get_selected_items().empty());
+  const auto some_selected = !(get_selected_items().empty());
 
   Glib::RefPtr<Goocanvas::Item> root = get_root_item();
   Glib::RefPtr<Goocanvas::Group> root_group = Glib::RefPtr<Goocanvas::Group>::cast_dynamic(root);
@@ -128,7 +128,7 @@ void CanvasEditable::remove_all_items()
 
 void CanvasEditable::remove_all_items(const Glib::RefPtr<Goocanvas::Group>& group)
 {
- const bool some_selected = !(get_selected_items().empty());
+ const auto some_selected = !(get_selected_items().empty());
 
   while(group && group->get_n_children())
       group->remove_child(0);
@@ -164,9 +164,9 @@ CanvasEditable::type_vec_doubles CanvasEditable::get_vertical_rules() const
   return m_grid->get_vertical_rules();
 }
 
-void CanvasEditable::show_temp_rule(double x, double y, bool show)
+void CanvasEditable::show_temp_rule(double x, double y, bool show_rule)
 {
-  m_grid->show_temp_rule(x, y, show);
+  m_grid->show_temp_rule(x, y, show_rule);
 }
 
 void CanvasEditable::set_grid_gap(double gap)
@@ -198,16 +198,13 @@ CanvasEditable::type_signal_selection_changed CanvasEditable::signal_selection_c
 
 void CanvasEditable::on_item_selected(const Glib::RefPtr<CanvasItemMovable>& item, bool group_select)
 {
-  const bool selected = !item->get_selected();
+  const auto selected = !item->get_selected();
 
   if(!group_select)
   {
     //Make sure that all other items are deselected first:
-    const type_vec_items items = get_selected_items();
-    for(type_vec_items::const_iterator iter = items.begin();
-      iter != items.end(); ++iter)
+    for(const auto& selected_item : get_selected_items())
     {
-      Glib::RefPtr<CanvasItemMovable> selected_item = *iter;
       if(selected_item)
         selected_item->set_selected(false);
     }
