@@ -31,9 +31,9 @@ const bool Dialog_FlowTable::glade_developer(true);
 		
 Dialog_FlowTable::Dialog_FlowTable(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
-  m_entry_title(0),
-  m_spin_columns(0),
-  m_flowtable(0)
+  m_entry_title(nullptr),
+  m_spin_columns(nullptr),
+  m_flowtable(nullptr)
 {
   builder->get_widget("entry_title",  m_entry_title);
   builder->get_widget("spin_columns",  m_spin_columns);
@@ -56,7 +56,7 @@ Dialog_FlowTable::~Dialog_FlowTable()
 void Dialog_FlowTable::set_flowtable(FlowTableWithFields* flowtable)
 {
   m_flowtable = flowtable;
-  m_layoutgroup = sharedptr<LayoutGroup>::cast_dynamic(flowtable->get_layout_item());
+  m_layoutgroup = std::dynamic_pointer_cast<LayoutGroup>(flowtable->get_layout_item());
   m_entry_title->set_text(item_get_title(m_layoutgroup));
   m_spin_columns->set_value(m_layoutgroup->get_columns_count());
 }
