@@ -41,7 +41,7 @@ const bool DialogImageSaveProgress::glade_developer(false);
 
 DialogImageSaveProgress::DialogImageSaveProgress(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
-  m_data(0)
+  m_data(nullptr)
 {
   builder->get_widget("progress_bar", m_progress_bar);
 
@@ -109,7 +109,7 @@ void DialogImageSaveProgress::on_stream_write(const Glib::RefPtr<Gio::AsyncResul
 {
   try
   {
-    const gssize size = m_stream->write_finish(result);
+    const auto size = m_stream->write_finish(result);
     g_assert(size >= 0); // Would have thrown an exception otherwise
     
     // Set progress
