@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_UTILITYWIDGETS_FLOWTABLE_H
@@ -37,7 +37,7 @@ public:
   typedef Gtk::Container type_base;
 
   void add_widgets(Gtk::Widget& first, Gtk::Widget& second, bool expand_second = false);
-  void add_widgets(Gtk::Widget& first, bool expand = false); //override
+  void add_widgets(Gtk::Widget& first, bool expand = false);
  
   /** Show extra UI that is useful in RAD tools:
    */
@@ -63,7 +63,7 @@ protected:
    */
   type_const_list_widgets get_first_child_widgets() const;
 
-  virtual bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr);
+  virtual bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr) override;
 
 private:
 
