@@ -28,6 +28,7 @@
 #include "layoutwidgetfield.h"
 #include <gtkmm/frame.h>
 #include <gtkmm/builder.h>
+#include <gtkmm/scrolledwindow.h>
 #include <giomm/appinfo.h>
 #include <giomm/simpleactiongroup.h>
 #include <evince-view.h>
@@ -65,6 +66,8 @@ public:
   
 private:
   void init();
+  void init_widgets(bool use_evince);
+  void clear_image_from_widgets();
 
   virtual void on_size_allocate(Gtk::Allocation& allocation);
 
@@ -108,12 +111,13 @@ private:
   Gtk::Frame m_frame;
   
   //For anything supported by Evince:
+  Gtk::ScrolledWindow* m_ev_scrolled_window;
   EvView* m_ev_view;
   EvDocumentModel* m_ev_document_model;
   
   //For anything supported by GdkPixbuf,
   //or for representative thumbnails and icons:
-  Gtk::Image m_image;
+  Gtk::Image* m_image;
   Glib::RefPtr<Gdk::Pixbuf> m_pixbuf_original; //Only stored temporarily, because it could be big.
   Glib::RefPtr<Gdk::Pixbuf> m_pixbuf_clipboard; //When copy is used, store it here until it is pasted.
 
