@@ -65,7 +65,7 @@ void NotebookLabel::set_label (const Glib::ustring& title)
 
 AppWindow* NotebookLabel::get_appwindow()
 {
-  Gtk::Container* pWindow = get_toplevel();
+  auto pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
 
   return dynamic_cast<AppWindow*>(pWindow);
@@ -73,7 +73,7 @@ AppWindow* NotebookLabel::get_appwindow()
 
 void NotebookLabel::on_menu_new_group_activate()
 {
-  std::shared_ptr<LayoutGroup> group(new LayoutGroup());
+  auto group = std::make_shared<LayoutGroup>();
   group->set_title_original(_("New Group"));
   group->set_name(_("Group"));
   
@@ -130,8 +130,8 @@ void NotebookLabel::setup_menu(Gtk::Widget* /* widget */)
 
 bool NotebookLabel::on_button_press_event(GdkEventButton *button_event)
 {
-  AppWindow* pApp = get_appwindow();
-  if(pApp && pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
+  auto pApp = get_appwindow();
+  if(pApp && pApp->get_userlevel() == AppState::userlevels::DEVELOPER)
   {
     GdkModifierType mods;
     gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
