@@ -71,7 +71,7 @@ int main()
     Glom::Document document;
     document.set_allow_autosave(false);
     document.set_file_uri(file_uri);
-    document.set_hosting_mode(Glom::Document::HOSTING_MODE_POSTGRES_CENTRAL);
+    document.set_hosting_mode(Glom::Document::HostingMode::POSTGRES_CENTRAL);
     document.set_database_title_original(test_title);
     const auto saved = document.save();
     g_assert(saved);
@@ -92,7 +92,7 @@ int main()
   {
     Glom::Document document;
     document.set_file_uri(file_uri);
-    document.set_hosting_mode(Glom::Document::HOSTING_MODE_POSTGRES_CENTRAL);
+    document.set_hosting_mode(Glom::Document::HostingMode::POSTGRES_CENTRAL);
     document.set_allow_autosave();
     document.set_database_title_original(test_title);
     g_assert( !document.get_modified() );
