@@ -39,10 +39,8 @@ bool contains(const T_Container& container, const T_Value& name)
 template<typename T_Container>
 bool contains_named(const T_Container& container, const Glib::ustring& name)
 {
-  typedef typename T_Container::value_type::element_type type_item;
   typename T_Container::const_iterator iter =
-    std::find_if(container.begin(), container.end(),
-      Glom::predicate_FieldHasName<type_item>(name));
+    Glom::find_if_same_name(container, name);
   return iter != container.end();
 }
 
@@ -63,7 +61,11 @@ static bool get_group_named(const Glom::Document::type_list_groups& container, c
 {
   Glom::Document::type_list_groups::const_iterator iter =
     std::find_if(container.begin(), container.end(),
-      Glom::predicate_FieldHasName<Glom::GroupInfo>(name));
+      [&name] (const Glom::GroupInfo& info)
+      {
+        return info.get_name() == name;
+      }
+    );
   if(iter != container.end())
   {
     group_info = *iter;
@@ -190,12 +192,12 @@ int main()
   std::shared_ptr<const Glom::Field> field = document.get_field("contacts", "contact_id");
   g_assert(field);
   g_assert( field->get_title_original() == "Contact ID" );
-  g_assert(field->get_glom_type() == Glom::Field::TYPE_NUMERIC);
+  g_assert(field->get_glom_type() == Glom::Field::glom_field_type::NUMERIC);
   g_assert(field->get_auto_increment());
   field = document.get_field("locations", "rent");
   g_assert(field);
   g_assert( field->get_title_original() == "Rent" );
-  g_assert(field->get_glom_type() == Glom::Field::TYPE_NUMERIC);
+  g_assert(field->get_glom_type() == Glom::Field::glom_field_type::NUMERIC);
   g_assert(!field->get_auto_increment());
   g_assert(!field->get_unique_key());
 
@@ -233,9 +235,9 @@ int main()
   //Check Field Formatting:
   field = document.get_field("contacts", "name_title");  
   g_assert(field);
-  g_assert(field->get_glom_type() == Glom::Field::TYPE_TEXT);
+  g_assert(field->get_glom_type() == Glom::Field::glom_field_type::TEXT);
   const Glom::Formatting& formatting = field->m_default_formatting;
-  g_assert(formatting.get_horizontal_alignment() == Glom::Formatting::HORIZONTAL_ALIGNMENT_AUTO);
+  g_assert(formatting.get_horizontal_alignment() == Glom::Formatting::HorizontalAlignment::AUTO);
   
   g_assert(formatting.get_has_choices());
   g_assert(formatting.get_has_custom_choices());
