@@ -55,7 +55,7 @@ int main()
   Glom::Document document;
   document.set_file_uri(uri);
   int failure_code = 0;
-  const bool test = document.load(failure_code);
+  const auto test = document.load(failure_code);
   //std::cout << "Document load result=" << test << std::endl;
 
   if(!test)
@@ -72,7 +72,7 @@ int main()
   const Glom::Document::type_list_layout_groups groups = 
     document.get_data_layout_groups("details", "projects");
   g_assert(groups.size() == 3);
-  const Glom::sharedptr<const Glom::LayoutGroup> group =
+  const std::shared_ptr<const Glom::LayoutGroup> group =
     groups[0];
   g_assert(group);
   g_assert(group->get_name() == "overview");
@@ -81,13 +81,13 @@ int main()
     group->get_items();
   //std::cout << "size: " << items.size() << std::endl;
   g_assert(items.size() == 3);
-  Glom::sharedptr<const Glom::LayoutItem> item = items[2];
+  std::shared_ptr<const Glom::LayoutItem> item = items[2];
   g_assert(item);
-  Glom::sharedptr<const Glom::LayoutItem_Image> image_item =
-    Glom::sharedptr<const Glom::LayoutItem_Image>::cast_dynamic(item);
+  std::shared_ptr<const Glom::LayoutItem_Image> image_item =
+    std::dynamic_pointer_cast<const Glom::LayoutItem_Image>(item);
   g_assert(image_item);
 
-  const Gnome::Gda::Value value = image_item->get_image();
+  const auto value = image_item->get_image();
   g_assert(check_value_is_an_image(value));
 
   Glom::libglom_deinit();
