@@ -60,7 +60,8 @@ static bool do_test(Glom::Document::HostingMode hosting_mode, const Glib::ustrin
   }
 
   const auto table_names = Glom::DbUtils::get_table_names_from_database();
-  if(Glom::Utils::find_exists(table_names, renamed_table_name)) {
+  if(std::find(table_names.begin(), table_names.end(), renamed_table_name)
+    != table_names.end()) {
     std::cerr << G_STRFUNC << ": Failure: The dropped table seems to still exist." << std::endl;
     return false;
   }
