@@ -45,7 +45,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
   
   const Glib::ustring table_name = "invoice_lines";
  
-  const Glom::sharedptr<const Glom::LayoutItem_Field> field_with_choice = 
+  const std::shared_ptr<const Glom::LayoutItem_Field> field_with_choice = 
     get_field_on_layout(document, table_name, table_name, "product_id");
   if(!field_with_choice)
   {
@@ -78,7 +78,7 @@ int main()
 {
   Glom::libglom_init();
   
-  const int result = test_all_hosting_modes(sigc::ptr_fun(&test));
+  const auto result = test_all_hosting_modes(sigc::ptr_fun(&test));
 
   Glom::libglom_deinit();
 
