@@ -86,14 +86,14 @@ int main()
   setlocale(LC_ALL, "en_US.UTF-8");
 
 
-  if(!test(Glom::Document::HOSTING_MODE_POSTGRES_SELF))
+  if(!test(Glom::Document::HostingMode::POSTGRES_SELF))
   {
     std::cerr << G_STRFUNC << ": Failed with PostgreSQL" << std::endl;
     test_selfhosting_cleanup();
     return EXIT_FAILURE;
   }
   
-  if(!test(Glom::Document::HOSTING_MODE_SQLITE))
+  if(!test(Glom::Document::HostingMode::SQLITE))
   {
     std::cerr << G_STRFUNC << ": Failed with SQLite" << std::endl;
     test_selfhosting_cleanup();
