@@ -33,7 +33,7 @@ xmlpp::Element* create_element()
 
 static bool test_value(Glom::Field::glom_field_type field_type, const Gnome::Gda::Value& value)
 {
-  xmlpp::Element* element = create_element();
+  auto element = create_element();
   Glom::XmlUtils::set_node_text_child_as_value(element, value, field_type);
 
   const Gnome::Gda::Value value_retrieved =
@@ -56,18 +56,18 @@ int main()
   Glom::libglom_init();
 
   const Glib::ustring str = " Some value or other with a quote \" and leading space."; //Just to be awkward.
-  if(!test_value(Glom::Field::TYPE_TEXT, Gnome::Gda::Value(str)))
+  if(!test_value(Glom::Field::glom_field_type::TEXT, Gnome::Gda::Value(str)))
     return EXIT_FAILURE;
 
   const Glib::Date date(11, Glib::Date::MAY, 1973);
-  if(!test_value(Glom::Field::TYPE_DATE, Gnome::Gda::Value(date)))
+  if(!test_value(Glom::Field::glom_field_type::DATE, Gnome::Gda::Value(date)))
     return EXIT_FAILURE;
 
   Gnome::Gda::Time time = {10, 20, 30, 0, 0};
-  if(!test_value(Glom::Field::TYPE_TIME, Gnome::Gda::Value(time)))
+  if(!test_value(Glom::Field::glom_field_type::TIME, Gnome::Gda::Value(time)))
     return EXIT_FAILURE;
 
-  if(!test_value(Glom::Field::TYPE_NUMERIC, Glom::Conversions::parse_value((double)3.50l)))
+  if(!test_value(Glom::Field::glom_field_type::NUMERIC, Glom::Conversions::parse_value((double)3.50l)))
     return EXIT_FAILURE;
 
 
